@@ -11,17 +11,17 @@
 #   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #   License for the specific language governing permissions and limitations
 #   under the License.
+from http import HTTPStatus
 
 from oslo_log import log as logging
-from six.moves import http_client
 import webob
 
 from cinder.api import extensions
 from cinder.api.openstack import wsgi
+from cinder.policies import manageable_volumes as policy
 from cinder import volume
 
 LOG = logging.getLogger(__name__)
-authorize = extensions.extension_authorizer('volume', 'volume_unmanage')
 
 
 class VolumeUnmanageController(wsgi.Controller):
@@ -29,7 +29,7 @@ class VolumeUnmanageController(wsgi.Controller):
         super(VolumeUnmanageController, self).__init__(*args, **kwargs)
         self.volume_api = volume.API()
 
-    @wsgi.response(http_client.ACCEPTED)
+    @wsgi.response(HTTPStatus.ACCEPTED)
     @wsgi.action('os-unmanage')
     def unmanage(self, req, id, body):
         """Stop managing a volume.
@@ -47,14 +47,14 @@ class VolumeUnmanageController(wsgi.Controller):
         attached to an instance.
         """
         context = req.environ['cinder.context']
-        authorize(context)
 
         LOG.info("Unmanage volume with id: %s", id)
 
         # Not found exception will be handled at the wsgi level
         vol = self.volume_api.get(context, id)
+        context.authorize(policy.UNMANAGE_POLICY, target_obj=vol)
         self.volume_api.delete(context, vol, unmanage_only=True)
-        return webob.Response(status_int=http_client.ACCEPTED)
+        return webob.Response(status_int=HTTPStatus.ACCEPTED)
 
 
 class Volume_unmanage(extensions.ExtensionDescriptor):
