@@ -19,13 +19,13 @@ Module dedicated functions/classes dealing with rate limiting requests.
 
 import collections
 import copy
+from http import client as http_client
 import math
 import re
 import time
 
 from oslo_serialization import jsonutils
 from oslo_utils import importutils
-from six.moves import http_client
 import webob.dec
 import webob.exc
 
@@ -168,6 +168,7 @@ class Limit(object):
             "resetTime": int(self.next_request or self._get_time()),
         }
 
+
 # "Limit" format is a dictionary with the HTTP verb, human-readable URI,
 # a regular-expression to match, value and unit of measure (PER_DAY, etc.)
 
@@ -415,7 +416,7 @@ class WsgiLimiterProxy(object):
 
         resp = conn.getresponse()
 
-        if http_client.OK >= resp.status < http_client.MULTIPLE_CHOICES:
+        if (resp.status >= 200) and (resp.status < 300):
             return None, None
 
         return resp.getheader("X-Wait-Seconds"), resp.read() or None
