@@ -32,7 +32,6 @@ from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_service import loopingcall
 from oslo_utils import excutils
-from oslo_utils import secretutils
 from oslo_utils import units
 
 from cinder.backup import driver
@@ -44,6 +43,8 @@ from cinder.volume import volume_utils
 
 if sys.platform == 'win32':
     from os_win import utilsfactory as os_win_utilsfactory
+else:
+    os_win_utilsfactory = None
 
 LOG = logging.getLogger(__name__)
 
@@ -69,13 +70,14 @@ CONF.register_opts(backup_opts)
 def _write_nonzero(volume_file, volume_offset, content):
     """Write non-zero parts of `content` into `volume_file`."""
     chunk_length = 1024 * 1024
+    content = memoryview(content)
     for chunk_offset in range(0, len(content), chunk_length):
         chunk_end = chunk_offset + chunk_length
         chunk = content[chunk_offset:chunk_end]
         # The len(chunk) may be smaller than chunk_length. It's okay.
         if not volume_utils.is_all_zero(chunk):
             volume_file.seek(volume_offset + chunk_offset)
-            volume_file.write(chunk)
+            volume_file.write(chunk.tobytes())
 
 
 def _write_volume(volume_is_new, volume_file, volume_offset, content):
@@ -398,7 +400,7 @@ class ChunkedBackupDriver(driver.BackupDriver, metaclass=abc.ABCMeta):
         ) as writer:
             writer.write(output_data)
         md5 = eventlet.tpool.execute(
-            secretutils.md5, data, usedforsecurity=False).hexdigest()
+            hashlib.md5, data, usedforsecurity=False).hexdigest()
         obj[object_name]['md5'] = md5
         LOG.debug('backup MD5 for %(object_name)s: %(md5)s',
                   {'object_name': object_name, 'md5': md5})
