@@ -60,13 +60,12 @@
                                   Ceilometer when backing up the volume to the
                                   S3 backend storage. (default: True)
 :backup_compression_algorithm: Compression algorithm to use for volume
-                               backups. Supported options are:
-                               None (to disable), zlib, bz2
-                               and zstd. (default: zlib)
+                               backups.
 """
 
 import base64
 import functools
+import hashlib
 import io
 import itertools as it
 import socket
@@ -78,7 +77,6 @@ from botocore.vendored.requests.packages.urllib3 import exceptions as \
     urrlib_exc
 from oslo_config import cfg
 from oslo_log import log as logging
-from oslo_utils.secretutils import md5
 from oslo_utils import timeutils
 
 from cinder.backup import chunkeddriver
@@ -201,6 +199,10 @@ class S3BackupDriver(chunkeddriver.ChunkedBackupDriver):
             'config': Config(**config_args)}
         if CONF.backup_s3_verify_ssl:
             conn_args['verify'] = CONF.backup_s3_ca_cert_file
+
+            if CONF.backup_s3_ca_cert_file is None:
+                LOG.warning('backup_s3_verify_ssl is True but no cert file '
+                            'was provided')
         else:
             conn_args['verify'] = False
         self.conn = boto3.client('s3', **conn_args)
@@ -323,7 +325,8 @@ class S3ObjectWriter(object):
     def close(self):
         reader = io.BytesIO(self.data)
         contentmd5 = base64.b64encode(
-            md5(self.data, usedforsecurity=False).digest()).decode('utf-8')
+            hashlib.md5(self.data,
+                        usedforsecurity=False).digest()).decode('utf-8')
         put_args = {'Bucket': self.bucket,
                     'Body': reader,
                     'Key': self.object_name,
