@@ -42,13 +42,12 @@
 :backup_swift_auth_insecure: If true, bypass verification of server's
                              certificate for SSL connections (default: False)
 """
-
+import hashlib
 import io
 import socket
 
 from oslo_config import cfg
 from oslo_log import log as logging
-from oslo_utils import secretutils
 from oslo_utils import timeutils
 from swiftclient import client as swift
 from swiftclient import exceptions as swift_exc
@@ -323,7 +322,7 @@ class SwiftBackupDriver(chunkeddriver.ChunkedBackupDriver):
                                             headers=headers)
             except socket.error as err:
                 raise exception.SwiftConnectionFailed(reason=err)
-            md5 = secretutils.md5(self.data, usedforsecurity=False).hexdigest()
+            md5 = hashlib.md5(self.data, usedforsecurity=False).hexdigest()
             if etag != md5:
                 err = _('error writing object to swift, MD5 of object in '
                         'swift %(etag)s is not the same as MD5 of object sent '
@@ -420,6 +419,9 @@ class SwiftBackupDriver(chunkeddriver.ChunkedBackupDriver):
                                     headers=self._headers())
         except socket.error as err:
             raise exception.SwiftConnectionFailed(reason=err)
+        except swift_exc.ClientException as err:
+            if err.http_status != 404:
+                raise
 
     def _generate_object_name_prefix(self, backup):
         """Generates a Swift backup object name prefix."""
