@@ -22,7 +22,7 @@ SHOULD include dedicated exception logging.
 
 """
 
-from typing import Optional, Union  # noqa: H301
+from typing import Optional, Union
 
 from oslo_log import log as logging
 from oslo_versionedobjects import exception as obj_exc
@@ -220,6 +220,11 @@ class InvalidVolume(Invalid):
     message = _("Invalid volume: %(reason)s")
 
 
+class ResourceConflict(Invalid):
+    message = _("Resource conflict: %(reason)s")
+    code = 409
+
+
 class InvalidContentType(Invalid):
     message = _("Invalid content type %(content_type)s.")
 
