@@ -16,8 +16,6 @@
 
 """Implementation of an image service that uses Glance as the backend"""
 
-from __future__ import annotations  # Remove when only supporting python 3.9+
-
 import copy
 import itertools
 import random
@@ -31,6 +29,7 @@ import urllib.parse
 
 import glanceclient
 import glanceclient.exc
+from keystoneauth1 import loading as ks_loading
 from keystoneauth1.loading import session as ks_session
 from oslo_config import cfg
 from oslo_log import log as logging
@@ -89,6 +88,14 @@ CONF = cfg.CONF
 CONF.register_opts(image_opts)
 CONF.register_opts(glance_core_properties_opts)
 
+# Register keystoneauth options to create service user
+# to talk to glance.
+GLANCE_GROUP = 'glance'
+glance_session_opts = ks_loading.get_session_conf_options()
+glance_auth_opts = ks_loading.get_auth_common_conf_options()
+CONF.register_opts(glance_session_opts, group=GLANCE_GROUP)
+CONF.register_opts(glance_auth_opts, group=GLANCE_GROUP)
+
 _SESSION = None
 
 LOG = logging.getLogger(__name__)
@@ -109,12 +116,17 @@ def _parse_image_ref(image_href: str) -> tuple[str, str, bool]:
     return (image_id, netloc, use_ssl)
 
 
-def _create_glance_client(context: context.RequestContext,
-                          netloc: str,
-                          use_ssl: bool) -> glanceclient.Client:
+def _create_glance_client(
+        context: context.RequestContext,
+        netloc: str,
+        use_ssl: bool,
+        privileged_user: bool = False) -> glanceclient.Client:
     """Instantiate a new glanceclient.Client object."""
     params = {'global_request_id': context.global_id}
-
+    g_auth = None
+    if privileged_user and CONF[GLANCE_GROUP].auth_type:
+        LOG.debug('Creating Keystone auth plugin from conf')
+        g_auth = ks_loading.load_auth_from_conf_options(CONF, GLANCE_GROUP)
     if use_ssl and CONF.auth_strategy == 'noauth':
         params = {'insecure': CONF.glance_api_insecure,
                   'cacert': CONF.glance_ca_certificates_file,
@@ -133,7 +145,7 @@ def _create_glance_client(context: context.RequestContext,
                               }
             _SESSION = ks_session.Session().load_from_options(**config_options)
 
-        auth = service_auth.get_auth_plugin(context)
+        auth = service_auth.get_auth_plugin(context, auth=g_auth)
         params['auth'] = auth
         params['session'] = _SESSION
 
@@ -188,44 +200,51 @@ class GlanceClientWrapper(object):
     def __init__(self,
                  context: Optional[context.RequestContext] = None,
                  netloc: Optional[str] = None,
-                 use_ssl: bool = False):
+                 use_ssl: bool = False,
+                 privileged_user: bool = False):
         self.client: Optional[glanceclient.Client]
         if netloc is not None:
             assert context is not None
             self.client = self._create_static_client(context,
                                                      netloc,
-                                                     use_ssl)
+                                                     use_ssl,
+                                                     privileged_user)
         else:
             self.client = None
         self.api_servers: Optional[Iterable] = None
 
-    def _create_static_client(self,
-                              context: context.RequestContext,
-                              netloc: str,
-                              use_ssl: bool) -> glanceclient.Client:
+    def _create_static_client(
+            self,
+            context: context.RequestContext,
+            netloc: str,
+            use_ssl: bool,
+            privileged_user: bool = False) -> glanceclient.Client:
         """Create a client that we'll use for every call."""
         self.netloc = netloc
         self.use_ssl = use_ssl
         return _create_glance_client(context,
                                      self.netloc,
-                                     self.use_ssl)
+                                     self.use_ssl,
+                                     privileged_user)
 
     def _create_onetime_client(
             self,
-            context: context.RequestContext) -> glanceclient.Client:
+            context: context.RequestContext,
+            privileged_user: bool = False) -> glanceclient.Client:
         """Create a client that will be used for one call."""
         if self.api_servers is None:
             self.api_servers = get_api_servers(context)
         self.netloc, self.use_ssl = next(self.api_servers)  # type: ignore
         return _create_glance_client(context,
                                      self.netloc,
-                                     self.use_ssl)
+                                     self.use_ssl,
+                                     privileged_user)
 
     def call(self,
              context: context.RequestContext,
              method: str,
              *args: Any,
-             **kwargs: str) -> Any:
+             **kwargs: Any) -> Any:
         """Call a glance client method.
 
         If we get a connection error,
@@ -239,9 +258,11 @@ class GlanceClientWrapper(object):
         glance_controller = kwargs.pop('controller', 'images')
         store_id = kwargs.pop('store_id', None)
         base_image_ref = kwargs.pop('base_image_ref', None)
+        privileged_user = kwargs.pop('privileged_user', False)
 
         for attempt in range(1, num_attempts + 1):
-            client = self.client or self._create_onetime_client(context)
+            client = self.client or self._create_onetime_client(
+                context, privileged_user)
 
             keys = ('x-image-meta-store', 'x-openstack-base-image-ref',)
             values = (store_id, base_image_ref,)
@@ -353,21 +374,64 @@ class GlanceImageService(object):
         the backend storage location, or (None, None) if these attributes are
         not shown by Glance.
         """
-        try:
-            # direct_url is returned by v2 api
-            client = GlanceClientWrapper()
-            image_meta = client.call(context, 'get', image_id)
-        except Exception:
-            _reraise_translated_image_exception(image_id)
+        # direct_url is returned by v2 api
+        client = GlanceClientWrapper()
+        # The ``get_image_locations`` API was added to address
+        # OSSN-0065, however to keep backward compatibility,
+        # we need to try with the old ``get`` call if we are using
+        # an older version of glance.
+        # TODO: Remove the ``get`` API call when 2024.1 trasitions
+        # to unmaintained. (``get_image_locations`` was added in 2024.2).
+        image_meta = {}
+        try_methods = ('get_image_locations', 'get')
+        for method in try_methods:
+            try:
+                # NOTE(gmaan): Glance get_image_locations API policy rule is
+                # default to 'service' role so cinder needs to load the auth
+                # plugin from the keystoneauth which has the 'service' role.
+                privileged_user = False
+                if method == 'get_image_locations':
+                    privileged_user = True
+                image_meta = client.call(context, method, image_id,
+                                         privileged_user=privileged_user)
+                if image_meta:
+                    break
+            except glanceclient.exc.HTTPNotImplemented:
+                LOG.debug('Glance method %s not available', method)
+            except glanceclient.exc.HTTPForbidden:
+                # In an upgrade scenario, if the operator hasn't configured
+                # the [glance] section in the cinder configuration file, we
+                # will fail on the new location GET API policy check.
+                LOG.warning('Glance method %s is available but a dedicated '
+                            '[glance] section is required in the cinder '
+                            'configuration file to allow service-to-service '
+                            'communication.', method)
+            except Exception:
+                _reraise_translated_image_exception(image_id)
 
         if not self._is_image_available(context, image_meta):
             raise exception.ImageNotFound(image_id=image_id)
 
+        locations: list[Any] = []
+        # Since both (old and new) APIs return RequestIdProxy object,
+        # to differentiate, we check the 'direct_url' property and if
+        # it exists then it's the old API (otherwise new)
+        direct_url = getattr(image_meta, 'direct_url', None)
+        if direct_url:
+            # Old format
+            locations = getattr(image_meta, 'locations', [])
+        else:
+            # New format (iterator)
+            # Verify that all location entries are in dict format
+            # Example: {'url': <url>, 'metadata': {'store': <store>}}
+            locations = [meta for meta in image_meta
+                         if isinstance(meta, dict)]
+
         # some glance stores like nfs only meta data
         # is stored and returned as locations.
         # so composite of two needs to be returned.
-        return (getattr(image_meta, 'direct_url', None),
-                getattr(image_meta, 'locations', None))
+        # direct_url will be None when using new location APIs
+        return (direct_url, locations)
 
     def add_location(self,
                      context: context.RequestContext,
@@ -379,11 +443,34 @@ class GlanceImageService(object):
         Returns a dict containing image metadata on success.
         """
         client = GlanceClientWrapper()
-        try:
-            return client.call(context, 'add_location',
-                               image_id, url, metadata)
-        except Exception:
-            _reraise_translated_image_exception(image_id)
+        # The ``add_image_location`` API was added to address
+        # OSSN-0065, however to keep backward compatibility,
+        # we need to try with the old ``add_location`` call
+        # if we are using an older version of glance.
+        # TODO: Remove the ``add_location`` API call when 2024.1
+        # trasitions to unmaintained. (``add_image_location``
+        # was added in 2024.2).
+        try_methods = ('add_image_location', 'add_location')
+        for method in try_methods:
+            try:
+                # NOTE(gmaan): Glance add_image_location API policy rule is
+                # default to 'service' role so cinder needs to load the auth
+                # plugin from the keystoneauth which has the 'service' role.
+                if method == 'add_image_location':
+                    privileged_user = True
+                else:
+                    privileged_user = False
+                return client.call(context, method,
+                                   image_id, url, metadata,
+                                   privileged_user=privileged_user)
+            except glanceclient.exc.HTTPNotImplemented:
+                LOG.debug('Glance method %s not available', method)
+            except Exception:
+                _reraise_translated_image_exception(image_id)
+        # If both method return HTTPNotImplemented exception
+        raise exception.ProgrammingError(
+            reason='unwarranted assumption about available glanceclient '
+            'methods.')
 
     def download(self,
                  context: context.RequestContext,
