@@ -44,6 +44,7 @@ from cinder.i18n import _
 
 key_mgr_opts = [
     cfg.StrOpt('fixed_key',
+               secret=True,
                help='Fixed key returned by key manager, specified in hex',
                deprecated_group='keymgr'),
 ]
@@ -145,6 +146,16 @@ class ConfKeyManager(key_manager.KeyManager):
 
         LOG.warning("Not deleting key %s", managed_object_id)
 
+    def add_consumer(self, context, managed_object_id, consumer_data):
+        raise NotImplementedError(
+            'ConfKeyManager does not implement adding consumers'
+        )
+
+    def remove_consumer(self, context, managed_object_id, consumer_data):
+        raise NotImplementedError(
+            'ConfKeyManager does not implement removing consumers'
+        )
+
     def list(self, context, object_type=None, metadata_only=False):
         """Retrieves a list of managed objects that match the criteria.
 
