@@ -44,6 +44,7 @@ class Service(base.CinderPersistentObject, base.CinderObject,
 
     OPTIONAL_FIELDS = ('cluster',)
 
+    # NOTE: When adding a field obj_make_compatible needs to be updated
     fields = {
         'id': fields.IntegerField(),
         'host': fields.StringField(nullable=True),
@@ -70,19 +71,6 @@ class Service(base.CinderPersistentObject, base.CinderObject,
         'uuid': fields.StringField(),
     }
 
-    def obj_make_compatible(self, primitive, target_version):
-        """Make a service representation compatible with a target version."""
-        # Convert all related objects
-        super(Service, self).obj_make_compatible(primitive, target_version)
-
-        target_version = versionutils.convert_version_to_tuple(target_version)
-        # Before v1.4 we didn't have cluster fields so we have to remove them.
-        if target_version < (1, 4):
-            for obj_field in ('cluster', 'cluster_name'):
-                primitive.pop(obj_field, None)
-        if target_version < (1, 5) and 'uuid' in primitive:
-            del primitive['uuid']
-
     @staticmethod
     def _from_db_object(context, service, db_service, expected_attrs=None):
         expected_attrs = expected_attrs or []
@@ -112,13 +100,6 @@ class Service(base.CinderPersistentObject, base.CinderObject,
 
         service.obj_reset_changes()
 
-        # TODO(jdg): Remove in S when we're sure all Services have UUID in db
-        if 'uuid' not in service:
-            service.uuid = uuidutils.generate_uuid()
-            LOG.debug('Generated UUID %(uuid)s for service %(id)i',
-                      dict(uuid=service.uuid, id=service.id))
-            service.save()
-
         return service
 
     def obj_load_attr(self, attrname):
@@ -142,8 +123,8 @@ class Service(base.CinderPersistentObject, base.CinderObject,
         self.obj_reset_changes(fields=(attrname,))
 
     @classmethod
-    def get_by_host_and_topic(cls, context, host, topic):
-        db_service = db.service_get(context, disabled=False, host=host,
+    def get_by_host_and_topic(cls, context, host, topic, disabled=False):
+        db_service = db.service_get(context, disabled=disabled, host=host,
                                     topic=topic)
         return cls._from_db_object(context, cls(context), db_service)
 
@@ -172,13 +153,13 @@ class Service(base.CinderPersistentObject, base.CinderObject,
         db_service = db.service_create(self._context, updates)
         self._from_db_object(self._context, self, db_service)
 
-    def save(self):
+    def save(self, retry=True):
         updates = self.cinder_obj_get_changes()
         if 'cluster' in updates:
             raise exception.ObjectActionError(
                 action='save', reason=_('cluster changed'))
         if updates:
-            db.service_update(self._context, self.id, updates)
+            db.service_update(self._context, self.id, updates, retry)
             self.obj_reset_changes()
 
     def destroy(self):
