@@ -13,7 +13,6 @@
 #    under the License.
 
 from oslo_config import cfg
-from oslo_utils import versionutils
 from oslo_versionedobjects import fields
 
 from cinder import db
@@ -53,8 +52,7 @@ class Snapshot(cleanable.CinderCleanableObject, base.CinderObject,
         'user_id': fields.StringField(nullable=True),
         'project_id': fields.StringField(nullable=True),
 
-        # TODO: (Y release) Change nullable to False
-        'use_quota': fields.BooleanField(default=True, nullable=True),
+        'use_quota': fields.BooleanField(default=True, nullable=False),
         'volume_id': fields.UUIDField(nullable=True),
         'cgsnapshot_id': fields.UUIDField(nullable=True),
         'group_snapshot_id': fields.UUIDField(nullable=True),
@@ -113,15 +111,6 @@ class Snapshot(cleanable.CinderCleanableObject, base.CinderObject,
             self._orig_metadata = (dict(self.metadata)
                                    if self.obj_attr_is_set('metadata') else {})
 
-    # TODO: (Y release) remove method
-    @classmethod
-    def _obj_from_primitive(cls, context, objver, primitive):
-        primitive['versioned_object.data'].setdefault('use_quota', True)
-        obj = super(Snapshot, Snapshot)._obj_from_primitive(context, objver,
-                                                            primitive)
-        obj._reset_metadata_tracking()
-        return obj
-
     def obj_what_changed(self):
         changes = super(Snapshot, self).obj_what_changed()
         if hasattr(self, 'metadata') and self.metadata != self._orig_metadata:
@@ -129,14 +118,6 @@ class Snapshot(cleanable.CinderCleanableObject, base.CinderObject,
 
         return changes
 
-    def obj_make_compatible(self, primitive, target_version):
-        """Make a Snapshot representation compatible with a target version."""
-        super(Snapshot, self).obj_make_compatible(primitive, target_version)
-        target_version = versionutils.convert_version_to_tuple(target_version)
-        # TODO: (Y release) remove next 2 lines & method if nothing else below
-        if target_version < (1, 6):
-            primitive.pop('use_quota', None)
-
     @classmethod
     def _from_db_object(cls, context, snapshot, db_snapshot,
                         expected_attrs=None):
@@ -199,8 +180,6 @@ class Snapshot(cleanable.CinderCleanableObject, base.CinderObject,
             updates['volume_type_id'] = (
                 volume_types.get_default_volume_type()['id'])
 
-        # TODO: (Y release) remove setting use_quota default, it's set by ORM
-        updates.setdefault('use_quota', True)
         db_snapshot = db.snapshot_create(self._context, updates)
         self._from_db_object(self._context, self, db_snapshot)
 
