@@ -38,10 +38,6 @@ from cinder.volume import api as volume_api
 CONF = cfg.CONF
 
 
-def return_create_volume_metadata_max(context, volume_id, metadata, delete):
-    return fake_max_volume_metadata()
-
-
 def return_create_volume_metadata(context, volume_id, metadata,
                                   delete, meta_type):
     return fake_volume_metadata()
@@ -90,13 +86,6 @@ def fake_volume_metadata_insensitive():
     return metadata
 
 
-def fake_max_volume_metadata():
-    metadata = {"metadata": {}}
-    for num in range(CONF.quota_metadata_items):
-        metadata['metadata']['key%i' % num] = "blah"
-    return metadata
-
-
 def get_volume(*args, **kwargs):
     vol = {'name': 'fake',
            'metadata': {},
