@@ -18,6 +18,7 @@
 from unittest import mock
 
 import ddt
+import webob
 
 from cinder.api import microversions as mv
 from cinder.api.v3 import attachments as v3_attachments
@@ -140,6 +141,113 @@ class AttachmentsAPITestCase(test.TestCase):
                           self.controller.update, req,
                           self.attachment1.id, body=body)
 
+    @mock.patch.object(volume_api.API, 'attachment_update')
+    def test_update_attachment_not_authorized(self, mock_update):
+        exc = exception.NotAuthorized(reason='Operation is not authorized.')
+        mock_update.side_effect = exc
+        req = fakes.HTTPRequest.blank('/v3/%s/attachments/%s' %
+                                      (fake.PROJECT_ID, self.attachment1.id),
+                                      version=mv.NEW_ATTACH,
+                                      use_admin_context=True)
+        body = {
+            "attachment":
+                {
+                    "connector": {'fake_key': 'fake_value',
+                                  'host': 'somehost',
+                                  'connection_info': 'a'},
+                },
+        }
+
+        self.assertRaises(exception.NotAuthorized,
+                          self.controller.update, req,
+                          self.attachment1.id, body=body)
+
+    @mock.patch('cinder.volume.api.API.attachment_update')
+    def test_update_attachment_invalid_volume_conflict(self, mock_update):
+        exc = exception.ResourceConflict(
+            reason='Duplicate connectors or improper volume status')
+        mock_update.side_effect = exc
+
+        req = fakes.HTTPRequest.blank('/v3/%s/attachments/%s' %
+                                      (fake.PROJECT_ID, self.attachment1.id),
+                                      version=mv.NEW_ATTACH,
+                                      use_admin_context=True)
+        body = {
+            "attachment":
+                {
+                    "connector": {'fake_key': 'fake_value',
+                                  'host': 'somehost',
+                                  'connection_info': 'a'},
+                },
+        }
+
+        self.assertRaises(exception.ResourceConflict,
+                          self.controller.update, req,
+                          self.attachment1.id, body=body)
+
+    @mock.patch.object(volume_api.API, 'attachment_update')
+    def test_update_attachment_generic_exception_invalid(self, mock_update):
+        exc = exception.Invalid(reason='Invalid class generic Exception')
+        mock_update.side_effect = exc
+        req = fakes.HTTPRequest.blank('/v3/%s/attachments/%s' %
+                                      (fake.PROJECT_ID, self.attachment1.id),
+                                      version=mv.NEW_ATTACH,
+                                      use_admin_context=True)
+        body = {
+            "attachment":
+                {
+                    "connector": {'fake_key': 'fake_value',
+                                  'host': 'somehost',
+                                  'connection_info': 'a'},
+                },
+        }
+
+        self.assertRaises(exception.Invalid,
+                          self.controller.update, req,
+                          self.attachment1.id, body=body)
+
+    @mock.patch.object(volume_api.API, 'attachment_update')
+    def test_update_attachment_cinder_exception(self, mock_update):
+        exc = exception.CinderException(reason='Generic Cinder Exception')
+        mock_update.side_effect = exc
+        req = fakes.HTTPRequest.blank('/v3/%s/attachments/%s' %
+                                      (fake.PROJECT_ID, self.attachment1.id),
+                                      version=mv.NEW_ATTACH,
+                                      use_admin_context=True)
+        body = {
+            "attachment":
+                {
+                    "connector": {'fake_key': 'fake_value',
+                                  'host': 'somehost',
+                                  'connection_info': 'a'},
+                },
+        }
+
+        self.assertRaises(webob.exc.HTTPInternalServerError,
+                          self.controller.update, req,
+                          self.attachment1.id, body=body)
+
+    @mock.patch.object(volume_api.API, 'attachment_update')
+    def test_update_attachment_all_other_exceptions(self, mock_update):
+        exc = Exception('The most generic Exception')
+        mock_update.side_effect = exc
+        req = fakes.HTTPRequest.blank('/v3/%s/attachments/%s' %
+                                      (fake.PROJECT_ID, self.attachment1.id),
+                                      version=mv.NEW_ATTACH,
+                                      use_admin_context=True)
+        body = {
+            "attachment":
+                {
+                    "connector": {'fake_key': 'fake_value',
+                                  'host': 'somehost',
+                                  'connection_info': 'a'},
+                },
+        }
+
+        self.assertRaises(webob.exc.HTTPInternalServerError,
+                          self.controller.update, req,
+                          self.attachment1.id, body=body)
+
     @ddt.data(mv.get_prior_version(mv.RESOURCE_FILTER),
               mv.RESOURCE_FILTER, mv.LIKE_FILTER)
     @mock.patch('cinder.api.common.reject_invalid_filters')
@@ -159,6 +267,8 @@ class AttachmentsAPITestCase(test.TestCase):
     @ddt.data('reserved', 'attached')
     @mock.patch.object(volume_rpcapi.VolumeAPI, 'attachment_delete')
     def test_delete_attachment(self, status, mock_delete):
+        self.patch('cinder.volume.api.API.attachment_deletion_allowed',
+                   return_value=None)
         volume1 = self._create_volume(display_name='fake_volume_1',
                                       project_id=fake.PROJECT_ID)
         attachment = self._create_attachment(
