@@ -26,8 +26,8 @@ from cinder.api.openstack import api_version_request as api_version
 from cinder.api.v3 import clusters
 from cinder import context
 from cinder import exception
-from cinder import test
 from cinder.tests.unit import fake_cluster
+from cinder.tests.unit import test
 
 
 CLUSTERS = [
@@ -243,7 +243,7 @@ class ClustersTestCase(test.TestCase):
                 return_value=CLUSTERS_ORM[1])
     def test_update_enable(self, get_mock, update_mock):
         req = FakeRequest()
-        expected = {'cluster': {'name': u'cluster2',
+        expected = {'cluster': {'name': 'cluster2',
                                 'binary': 'cinder-volume',
                                 'state': 'down',
                                 'status': 'enabled',
@@ -266,7 +266,7 @@ class ClustersTestCase(test.TestCase):
     def test_update_disable(self, get_mock, update_mock):
         req = FakeRequest()
         disabled_reason = 'For testing'
-        expected = {'cluster': {'name': u'cluster_name',
+        expected = {'cluster': {'name': 'cluster_name',
                                 'state': 'up',
                                 'binary': 'cinder-volume',
                                 'status': 'disabled',
