@@ -11,18 +11,20 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import HTTPStatus
+
 import ddt
-from six.moves import http_client
 import webob
 
+from cinder.api import microversions as mv
 from cinder.api.openstack import api_version_request as api_version
 from cinder.api.v3 import consistencygroups
 from cinder import context
 from cinder import objects
 from cinder.objects import fields
-from cinder import test
 from cinder.tests.unit.api import fakes
 from cinder.tests.unit import fake_constants as fake
+from cinder.tests.unit import test
 
 
 @ddt.ddt
@@ -72,9 +74,10 @@ class ConsistencyGroupsAPITestCase(test.TestCase):
         req = fakes.HTTPRequest.blank('/v3/%s/consistencygroups/%s/update' %
                                       (fake.PROJECT_ID, consistencygroup.id))
         req.environ['cinder.context'].is_admin = True
+        req.headers = mv.get_mv_header(mv.CG_UPDATE_BLANK_PROPERTIES)
         req.headers['Content-Type'] = 'application/json'
-        req.headers['OpenStack-API-Version'] = 'volume 3.6'
-        req.api_version_request = api_version.APIVersionRequest('3.6')
+        req.api_version_request = mv.get_api_version(
+            mv.CG_UPDATE_BLANK_PROPERTIES)
         body = {"consistencygroup": {"name": "",
                                      "description": "",
                                      "add_volumes": None,
@@ -84,7 +87,7 @@ class ConsistencyGroupsAPITestCase(test.TestCase):
                                           body)
         consistencygroup = objects.Group.get_by_id(
             self.ctxt, consistencygroup.id)
-        self.assertEqual(http_client.ACCEPTED, res_dict.status_int)
+        self.assertEqual(HTTPStatus.ACCEPTED, res_dict.status_int)
         self.assertEqual("", consistencygroup.name)
         self.assertEqual("", consistencygroup.description)
         consistencygroup.destroy()
@@ -103,12 +106,12 @@ class ConsistencyGroupsAPITestCase(test.TestCase):
                                      "description": "",
                                      "add_volumes": None,
                                      "remove_volumes": None, }}
-        self.assertRaisesRegexp(webob.exc.HTTPBadRequest,
-                                "Name, description, add_volumes, "
-                                "and remove_volumes can not be all "
-                                "empty in the request body.",
-                                self.controller.update,
-                                req, consistencygroup.id, body)
+        self.assertRaisesRegex(webob.exc.HTTPBadRequest,
+                               "Name, description, add_volumes, "
+                               "and remove_volumes can not be all "
+                               "empty in the request body.",
+                               self.controller.update,
+                               req, consistencygroup.id, body)
         consistencygroup.destroy()
 
     def test_update_consistencygroup_all_empty_parameters_version_36(self):
@@ -118,39 +121,44 @@ class ConsistencyGroupsAPITestCase(test.TestCase):
         req = fakes.HTTPRequest.blank('/v3/%s/consistencygroups/%s/update' %
                                       (fake.PROJECT_ID, consistencygroup.id))
         req.environ['cinder.context'].is_admin = True
+        req.headers = mv.get_mv_header(mv.CG_UPDATE_BLANK_PROPERTIES)
         req.headers['Content-Type'] = 'application/json'
-        req.headers['OpenStack-API-Version'] = 'volume 3.6'
-        req.api_version_request = api_version.APIVersionRequest('3.6')
+        req.api_version_request = mv.get_api_version(
+            mv.CG_UPDATE_BLANK_PROPERTIES)
         body = {"consistencygroup": {"name": None,
                                      "description": None,
                                      "add_volumes": None,
                                      "remove_volumes": None, }}
-        self.assertRaisesRegexp(webob.exc.HTTPBadRequest, "Must specify "
-                                "one or more of the following keys to "
-                                "update: name, description, add_volumes, "
-                                "remove_volumes.", self.controller.update,
-                                req, consistencygroup.id, body)
+        self.assertRaisesRegex(webob.exc.HTTPBadRequest, "Must specify "
+                               "one or more of the following keys to "
+                               "update: name, description, add_volumes, "
+                               "remove_volumes.", self.controller.update,
+                               req, consistencygroup.id, body)
         consistencygroup.destroy()
 
-    def test_update_consistencygroup_all_empty_parameters_not_version_36(self):
+    def test_update_consistencygroup_all_empty_parameters_not_version_ok(self):
         consistencygroup = self._create_consistencygroup(
             ctxt=self.ctxt,
             status=fields.ConsistencyGroupStatus.AVAILABLE)
         req = fakes.HTTPRequest.blank('/v3/%s/consistencygroups/%s/update' %
                                       (fake.PROJECT_ID, consistencygroup.id))
         req.environ['cinder.context'].is_admin = True
+
+        non_supported_version = mv.get_prior_version(
+            mv.CG_UPDATE_BLANK_PROPERTIES)
+        req.headers = mv.get_mv_header(non_supported_version)
+        req.api_version_request = mv.get_api_version(non_supported_version)
         req.headers['Content-Type'] = 'application/json'
-        req.headers['OpenStack-API-Version'] = 'volume 3.5'
-        req.api_version_request = api_version.APIVersionRequest('3.5')
+
         body = {"consistencygroup": {"name": None,
                                      "description": None,
                                      "add_volumes": None,
                                      "remove_volumes": None, }}
-        self.assertRaisesRegexp(webob.exc.HTTPBadRequest, "Name, description, "
-                                "add_volumes, and remove_volumes can not be "
-                                "all empty in the request body.",
-                                self.controller.update,
-                                req, consistencygroup.id, body)
+        self.assertRaisesRegex(webob.exc.HTTPBadRequest, "Name, description, "
+                               "add_volumes, and remove_volumes can not be "
+                               "all empty in the request body.",
+                               self.controller.update,
+                               req, consistencygroup.id, body)
         consistencygroup.destroy()
 
     def test_update_consistencygroup_no_body(self):
@@ -160,14 +168,18 @@ class ConsistencyGroupsAPITestCase(test.TestCase):
         req = fakes.HTTPRequest.blank('/v3/%s/consistencygroups/%s/update' %
                                       (fake.PROJECT_ID, consistencygroup.id))
         req.environ['cinder.context'].is_admin = True
+
+        non_supported_version = mv.get_prior_version(
+            mv.CG_UPDATE_BLANK_PROPERTIES)
+        req.headers = mv.get_mv_header(non_supported_version)
+        req.api_version_request = mv.get_api_version(non_supported_version)
         req.headers['Content-Type'] = 'application/json'
-        req.headers['OpenStack-API-Version'] = 'volume 3.5'
-        req.api_version_request = api_version.APIVersionRequest('3.5')
+
         body = None
-        self.assertRaisesRegexp(webob.exc.HTTPBadRequest,
-                                "Missing request body",
-                                self.controller.update,
-                                req, consistencygroup.id, body)
+        self.assertRaisesRegex(webob.exc.HTTPBadRequest,
+                               "Missing request body",
+                               self.controller.update,
+                               req, consistencygroup.id, body)
         consistencygroup.destroy()
 
     def test_update_consistencygroups_no_empty_parameters(self):
@@ -177,9 +189,13 @@ class ConsistencyGroupsAPITestCase(test.TestCase):
         req = fakes.HTTPRequest.blank('/v3/%s/consistencygroups/%s/update' %
                                       (fake.PROJECT_ID, consistencygroup.id))
         req.environ['cinder.context'].is_admin = True
+
+        non_supported_version = mv.get_prior_version(
+            mv.CG_UPDATE_BLANK_PROPERTIES)
+        req.headers = mv.get_mv_header(non_supported_version)
         req.headers['Content-Type'] = 'application/json'
-        req.headers['OpenStack-API-Version'] = 'volume 3.5'
-        req.api_version_request = api_version.APIVersionRequest('3.5')
+
+        req.api_version_request = mv.get_api_version(non_supported_version)
         body = {"consistencygroup": {"name": "my_fake_cg",
                                      "description": "fake consistency group",
                                      "add_volumes": "volume-uuid-1",
