@@ -20,8 +20,8 @@ from cinder import db
 from cinder.db.sqlalchemy import api as db_api
 from cinder.db.sqlalchemy import models
 from cinder import exception
-from cinder import test
 from cinder.tests.unit import fake_constants as fake
+from cinder.tests.unit import test
 from cinder.tests.unit import utils
 
 
@@ -135,9 +135,12 @@ class TransfersTableTestCase(test.TestCase):
         db.transfer_accept(nctxt.elevated(), xfer_id, fake.USER2_ID,
                            fake.PROJECT2_ID)
 
-        xfer = db_api.model_query(
-            nctxt.elevated(), models.Transfer, read_deleted='yes'
-        ).filter_by(id=xfer_id).first()
+        nctxt_admin = nctxt.elevated()
+
+        with db_api.main_context_manager.reader.using(nctxt_admin):
+            xfer = db_api.model_query(
+                nctxt_admin, models.Transfer, read_deleted='yes'
+            ).filter_by(id=xfer_id).first()
 
         self.assertEqual(volume.project_id, xfer['source_project_id'])
         self.assertTrue(xfer['accepted'])
