@@ -18,7 +18,7 @@
 
 import copy
 import datetime
-import mock
+from unittest import mock
 import uuid
 
 from cinder import exception
@@ -102,7 +102,6 @@ class _FakeImageService(object):
                   'updated_at': timestamp,
                   'deleted_at': None,
                   'deleted': False,
-                  'size': 1024,
                   'status': 'active',
                   'visibility': 'public',
                   'protected': True,
@@ -213,7 +212,7 @@ class _FakeImageService(object):
         return self.images[image_id]
 
     def update(self, context, image_id, metadata, data=None,
-               purge_props=False):
+               purge_props=False, store_id=None, base_image_ref=None):
         """Replace the contents of the given image with the new data.
 
         :raises ImageNotFound: if the image does not exist.
