@@ -15,11 +15,9 @@
 from unittest import mock
 
 import ddt
-import six
 
 from cinder import exception
 from cinder import objects
-from cinder.objects import base as ovo_base
 from cinder.objects import fields
 from cinder.tests.unit import fake_constants as fake
 from cinder.tests.unit import fake_volume
@@ -140,15 +138,11 @@ class TestGroup(test_objects.BaseObjectsTestCase):
         # new value for that field
         group.refresh()
         self._compare(self, db_group2, group)
-        if six.PY3:
-            call_bool = mock.call.__bool__()
-        else:
-            call_bool = mock.call.__nonzero__()
         group_get.assert_has_calls([
             mock.call(
                 self.context,
                 fake.GROUP_ID),
-            call_bool,
+            mock.call.__bool__(),
             mock.call(
                 self.context,
                 fake.GROUP_ID)])
@@ -164,22 +158,6 @@ class TestGroup(test_objects.BaseObjectsTestCase):
         self.assertEqual(len(db_volumes), len(group.volumes))
         self._compare(self, db_volumes[0], group.volumes[0])
 
-    @ddt.data('1.10', '1.11')
-    def test_obj_make_compatible(self, version):
-        extra_data = {'group_snapshot_id': fake.GROUP_SNAPSHOT_ID,
-                      'source_group_id': fake.GROUP_ID,
-                      'group_snapshots': objects.GroupSnapshotList()}
-        group = objects.Group(self.context, name='name', **extra_data)
-
-        serializer = ovo_base.CinderObjectSerializer(version)
-        primitive = serializer.serialize_entity(self.context, group)
-
-        converted_group = objects.Group.obj_from_primitive(primitive)
-        is_set = version == '1.11'
-        for key in extra_data:
-            self.assertEqual(is_set, converted_group.obj_attr_is_set(key))
-        self.assertEqual('name', converted_group.name)
-
     @mock.patch('cinder.volume.group_types.get_group_type_specs')
     def test_is_replicated_true(self, mock_get_specs):
         mock_get_specs.return_value = '<is> True'
