@@ -89,6 +89,9 @@ class VolumeActionsPolicyTest(base.BasePolicyTest):
             self._initialize_connection)
         self.api_path = '/v3/%s/volumes' % (self.project_id)
         self.api_version = mv.BASE_VERSION
+        self.mock_is_service = self.patch(
+            'cinder.volume.api.API.is_service_request',
+            return_value=True)
 
     def _initialize_connection(self, volume, connector):
         return {'data': connector}
@@ -946,6 +949,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
         self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
         body = {"os-detach": {}}
+        # Detach for user call succeeds because the volume has no attachments
         response = self._get_request_response(admin_context, path, 'POST',
                                               body=body)
         self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
@@ -966,6 +970,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
                                               body=body)
         self.assertEqual(HTTPStatus.ACCEPTED, response.status_int)
 
+        # Succeeds for a user call because there are no attachments
         body = {"os-detach": {}}
         response = self._get_request_response(user_context, path, 'POST',
                                               body=body)
@@ -1062,6 +1067,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
                        'terminate_connection')
     def test_admin_can_initialize_terminate_conn(self, mock_t, mock_i):
         admin_context = self.admin_context
+        admin_context.service_roles = ['service']
 
         volume = self._create_fake_volume(admin_context)
         path = '/v3/%(project_id)s/volumes/%(volume_id)s/action' % {
@@ -1084,6 +1090,7 @@ class VolumeProtectionTests(test_base.CinderPolicyTests):
                        'terminate_connection')
     def test_owner_can_initialize_terminate_conn(self, mock_t, mock_i):
         user_context = self.user_context
+        user_context.service_roles = ['service']
 
         volume = self._create_fake_volume(user_context)
         path = '/v3/%(project_id)s/volumes/%(volume_id)s/action' % {
