@@ -12,12 +12,11 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-"""
-Tests For Filter Scheduler.
-"""
+"""Tests For Filter Scheduler."""
+
+from unittest import mock
 
 import ddt
-import mock
 
 from cinder import context
 from cinder import exception
@@ -66,7 +65,6 @@ class FilterSchedulerTestCase(test_scheduler.SchedulerTestCase):
     def test_schedule_group(self, specs, _mock_service_get_all):
         # Make sure _schedule_group() can find host successfully.
         sched = fakes.FakeFilterScheduler()
-        sched.host_manager = fakes.FakeHostManager()
         fake_context = context.RequestContext('user', 'project',
                                               is_admin=True)
 
@@ -170,7 +168,6 @@ class FilterSchedulerTestCase(test_scheduler.SchedulerTestCase):
         # Make sure there's nothing glaringly wrong with _schedule()
         # by doing a happy day pass through.
         sched = fakes.FakeFilterScheduler()
-        sched.host_manager = fakes.FakeHostManager()
         fake_context = context.RequestContext('user', 'project',
                                               is_admin=True)
 
@@ -356,7 +353,6 @@ class FilterSchedulerTestCase(test_scheduler.SchedulerTestCase):
 
     def _backend_passes_filters_setup(self, mock_obj):
         sched = fakes.FakeFilterScheduler()
-        sched.host_manager = fakes.FakeHostManager()
         fake_context = context.RequestContext('user', 'project',
                                               is_admin=True)
 
