@@ -18,8 +18,8 @@ import sys
 from unittest import mock
 
 from cinder import context
-from cinder import test
 from cinder.tests.unit.targets import targets_fixture as tf
+from cinder.tests.unit import test
 from cinder import utils
 from cinder.volume.targets import cxt
 
@@ -43,7 +43,7 @@ class TestCxtAdmDriver(tf.TargetDriverFixture):
 
     def test_get_target(self):
         with mock.patch.object(self.target, '_get_volumes_dir',
-                               return_value=self.fake_volumes_dir),\
+                               return_value=self.fake_volumes_dir), \
             mock.patch('cinder.utils.execute',
                        return_value=(self.fake_iscsi_scan, None)) as m_exec:
             self.assertEqual(
