@@ -958,8 +958,9 @@ class DbQuotaDriverTestCase(DbQuotaDriverBaseTestCase):
     def test_get_class_quotas(self):
         self._mock_quota_class_get_all_by_name()
         self._mock_volume_type_get_all()
-        result = self.driver.get_class_quotas(None, quota.QUOTAS.resources,
-                                              'test_class')
+        ctxt = context.RequestContext('admin', 'admin', is_admin=True)
+        result = self.driver.get_class_quotas(
+            ctxt, quota.QUOTAS.resources, 'test_class')
 
         self.assertEqual(['quota_class_get_all_by_name'], self.calls)
         self.assertEqual(dict(volumes=10,
@@ -971,8 +972,9 @@ class DbQuotaDriverTestCase(DbQuotaDriverBaseTestCase):
 
     def test_get_class_quotas_no_defaults(self):
         self._mock_quota_class_get_all_by_name()
-        result = self.driver.get_class_quotas(None, quota.QUOTAS.resources,
-                                              'test_class', False)
+        ctxt = context.RequestContext('admin', 'admin', is_admin=True)
+        result = self.driver.get_class_quotas(
+            ctxt, quota.QUOTAS.resources, 'test_class', False)
 
         self.assertEqual(['quota_class_get_all_by_name'], self.calls)
         self.assertEqual(dict(volumes=10,
@@ -1390,16 +1392,11 @@ class QuotaReserveSqlAlchemyTestCase(test.TestCase):
         self.usages_created = {}
         self.reservations_created = {}
 
-        def fake_get_session():
-            return FakeSession()
-
-        def fake_get_quota_usages(context, session, project_id,
-                                  resources=None):
+        def fake_get_quota_usages(context, project_id, resources=None):
             return self.usages.copy()
 
         def fake_quota_usage_create(context, project_id, resource, in_use,
-                                    reserved, until_refresh, session=None,
-                                    save=True):
+                                    reserved, until_refresh):
             quota_usage_ref = self._make_quota_usage(
                 project_id, resource, in_use, reserved, until_refresh,
                 timeutils.utcnow(), timeutils.utcnow())
@@ -1409,7 +1406,7 @@ class QuotaReserveSqlAlchemyTestCase(test.TestCase):
             return quota_usage_ref
 
         def fake_reservation_create(context, uuid, usage_id, project_id,
-                                    resource, delta, expire, session=None):
+                                    resource, delta, expire):
             reservation_ref = self._make_reservation(
                 uuid, usage_id, project_id, resource, delta, expire,
                 timeutils.utcnow(), timeutils.utcnow())
@@ -1418,8 +1415,6 @@ class QuotaReserveSqlAlchemyTestCase(test.TestCase):
 
             return reservation_ref
 
-        self.mock_object(sqa_api, 'get_session',
-                         fake_get_session)
         self.mock_object(sqa_api, '_get_quota_usages',
                          fake_get_quota_usages)
         self.mock_object(sqa_api, '_quota_usage_create',
@@ -1511,7 +1506,7 @@ class QuotaReserveSqlAlchemyTestCase(test.TestCase):
     def test_quota_reserve_create_usages(self, usages_mock, quota_create_mock,
                                          sync_mock, reserve_mock):
         project_id = 'test_project'
-        context = FakeContext(project_id, 'test_class')
+        ctxt = context.RequestContext('admin', project_id, is_admin=True)
         quotas = collections.OrderedDict([('volumes', 5),
                                           ('gigabytes', 10 * 1024)])
         deltas = collections.OrderedDict([('volumes', 2),
@@ -1530,45 +1525,42 @@ class QuotaReserveSqlAlchemyTestCase(test.TestCase):
         reservations = [mock.Mock(), mock.Mock()]
         reserve_mock.side_effect = reservations
 
-        result = sqa_api.quota_reserve(context, self.resources, quotas,
+        result = sqa_api.quota_reserve(ctxt, self.resources, quotas,
                                        deltas, self.expire, 0, 0)
 
         self.assertEqual([r.uuid for r in reservations], result)
 
         usages_mock.assert_has_calls([
-            mock.call(mock.ANY, mock.ANY, project_id, resources=deltas.keys()),
-            mock.call(mock.ANY, mock.ANY, project_id, resources=deltas.keys())
+            mock.call(mock.ANY, project_id, resources=deltas.keys()),
+            mock.call(mock.ANY, project_id, resources=deltas.keys())
         ])
 
         sync_mock.assert_has_calls([
-            mock.call(mock.ANY, project_id, mock.ANY, self.resources,
-                      'volumes'),
-            mock.call(mock.ANY, project_id, mock.ANY, self.resources,
-                      'gigabytes')])
+            mock.call(mock.ANY, project_id, self.resources, 'volumes'),
+            mock.call(mock.ANY, project_id, self.resources, 'gigabytes'),
+        ])
 
         quota_create_mock.assert_has_calls([
-            mock.call(mock.ANY, project_id, 'volumes', 2, 0, None,
-                      session=mock.ANY),
-            mock.call(mock.ANY, project_id, 'gigabytes', 2 * 1024, 0, None,
-                      session=mock.ANY)
+            mock.call(mock.ANY, project_id, 'volumes', 2, 0, None),
+            mock.call(mock.ANY, project_id, 'gigabytes', 2 * 1024, 0, None)
         ])
 
         reserve_mock.assert_has_calls([
             mock.call(mock.ANY, mock.ANY, vol_usage, project_id, 'volumes',
-                      2, mock.ANY, session=mock.ANY),
+                      2, mock.ANY),
             mock.call(mock.ANY, mock.ANY, gb_usage, project_id, 'gigabytes',
-                      2 * 1024, mock.ANY, session=mock.ANY),
+                      2 * 1024, mock.ANY),
         ])
 
     def test_quota_reserve_negative_in_use(self):
         self.init_usage('test_project', 'volumes', -1, 0, until_refresh=1)
         self.init_usage('test_project', 'gigabytes', -1, 0, until_refresh=1)
-        context = FakeContext('test_project', 'test_class')
+        ctxt = context.RequestContext('admin', 'test_project', is_admin=True)
         quotas = dict(volumes=5,
                       gigabytes=10 * 1024, )
         deltas = dict(volumes=2,
                       gigabytes=2 * 1024, )
-        result = sqa_api.quota_reserve(context, self.resources, quotas,
+        result = sqa_api.quota_reserve(ctxt, self.resources, quotas,
                                        deltas, self.expire, 5, 0)
 
         self.assertEqual(set(['volumes', 'gigabytes']), self.sync_called)
@@ -1595,10 +1587,10 @@ class QuotaReserveSqlAlchemyTestCase(test.TestCase):
     def test_quota_reserve_until_refresh(self):
         self.init_usage('test_project', 'volumes', 3, 0, until_refresh=1)
         self.init_usage('test_project', 'gigabytes', 3, 0, until_refresh=1)
-        context = FakeContext('test_project', 'test_class')
+        ctxt = context.RequestContext('admin', 'test_project', is_admin=True)
         quotas = dict(volumes=5, gigabytes=10 * 1024, )
         deltas = dict(volumes=2, gigabytes=2 * 1024, )
-        result = sqa_api.quota_reserve(context, self.resources, quotas,
+        result = sqa_api.quota_reserve(ctxt, self.resources, quotas,
                                        deltas, self.expire, 5, 0)
 
         self.assertEqual(set(['volumes', 'gigabytes']), self.sync_called)
@@ -1628,12 +1620,12 @@ class QuotaReserveSqlAlchemyTestCase(test.TestCase):
         self.init_usage('test_project', 'volumes', 3, 0, until_refresh=None)
         self.init_usage('test_project', 'gigabytes', 100, 0,
                         until_refresh=None)
-        context = FakeContext('test_project', 'test_class')
+        ctxt = context.RequestContext('admin', 'test_project', is_admin=True)
         quotas = dict(volumes=5, gigabytes=10 * 1024, )
         deltas = dict(volumes=2, gigabytes=2 * 1024, )
 
         # Simulate service is now running with until_refresh set to 5
-        sqa_api.quota_reserve(context, self.resources, quotas, deltas,
+        sqa_api.quota_reserve(ctxt, self.resources, quotas, deltas,
                               self.expire, 5, 0)
 
         self.compare_usage(self.usages, [dict(resource='volumes',
@@ -1652,12 +1644,12 @@ class QuotaReserveSqlAlchemyTestCase(test.TestCase):
         # Simulate service running with until_refresh enabled and set to 5
         self.init_usage('test_project', 'volumes', 3, 0, until_refresh=5)
         self.init_usage('test_project', 'gigabytes', 100, 0, until_refresh=5)
-        context = FakeContext('test_project', 'test_class')
+        ctxt = context.RequestContext('admin', 'test_project', is_admin=True)
         quotas = dict(volumes=5, gigabytes=10 * 1024, )
         deltas = dict(volumes=2, gigabytes=2 * 1024, )
 
         # Simulate service is now running with until_refresh disabled
-        sqa_api.quota_reserve(context, self.resources, quotas, deltas,
+        sqa_api.quota_reserve(ctxt, self.resources, quotas, deltas,
                               self.expire, None, 0)
 
         self.compare_usage(self.usages, [dict(resource='volumes',
@@ -1679,10 +1671,10 @@ class QuotaReserveSqlAlchemyTestCase(test.TestCase):
                         created_at=record_created, updated_at=record_created)
         self.init_usage('test_project', 'gigabytes', 3, 0,
                         created_at=record_created, updated_at=record_created)
-        context = FakeContext('test_project', 'test_class')
+        ctxt = context.RequestContext('admin', 'test_project', is_admin=True)
         quotas = dict(volumes=5, gigabytes=10 * 1024, )
         deltas = dict(volumes=2, gigabytes=2 * 1024, )
-        result = sqa_api.quota_reserve(context, self.resources, quotas,
+        result = sqa_api.quota_reserve(ctxt, self.resources, quotas,
                                        deltas, self.expire, 0, max_age)
 
         self.assertEqual(set(['volumes', 'gigabytes']), self.sync_called)
@@ -1714,10 +1706,10 @@ class QuotaReserveSqlAlchemyTestCase(test.TestCase):
                         created_at=record_created, updated_at=record_created)
         self.init_usage('test_project', 'gigabytes', 3, 0,
                         created_at=record_created, updated_at=record_created)
-        context = FakeContext('test_project', 'test_class')
+        ctxt = context.RequestContext('admin', 'test_project', is_admin=True)
         quotas = dict(volumes=5, gigabytes=10 * 1024, )
         deltas = dict(volumes=2, gigabytes=2 * 1024, )
-        result = sqa_api.quota_reserve(context, self.resources, quotas,
+        result = sqa_api.quota_reserve(ctxt, self.resources, quotas,
                                        deltas, self.expire, 0, max_age)
 
         self.assertEqual(set(), self.sync_called)
@@ -1744,10 +1736,10 @@ class QuotaReserveSqlAlchemyTestCase(test.TestCase):
     def test_quota_reserve_no_refresh(self):
         self.init_usage('test_project', 'volumes', 3, 0)
         self.init_usage('test_project', 'gigabytes', 3, 0)
-        context = FakeContext('test_project', 'test_class')
+        ctxt = context.RequestContext('admin', 'test_project', is_admin=True)
         quotas = dict(volumes=5, gigabytes=10 * 1024, )
         deltas = dict(volumes=2, gigabytes=2 * 1024, )
-        result = sqa_api.quota_reserve(context, self.resources, quotas,
+        result = sqa_api.quota_reserve(ctxt, self.resources, quotas,
                                        deltas, self.expire, 0, 0)
 
         self.assertEqual(set([]), self.sync_called)
@@ -1774,10 +1766,10 @@ class QuotaReserveSqlAlchemyTestCase(test.TestCase):
     def test_quota_reserve_unders(self):
         self.init_usage('test_project', 'volumes', 1, 0)
         self.init_usage('test_project', 'gigabytes', 1 * 1024, 0)
-        context = FakeContext('test_project', 'test_class')
+        ctxt = context.RequestContext('admin', 'test_project', is_admin=True)
         quotas = dict(volumes=5, gigabytes=10 * 1024, )
         deltas = dict(volumes=-2, gigabytes=-2 * 1024, )
-        result = sqa_api.quota_reserve(context, self.resources, quotas,
+        result = sqa_api.quota_reserve(ctxt, self.resources, quotas,
                                        deltas, self.expire, 0, 0)
 
         self.assertEqual(set([]), self.sync_called)
@@ -1804,12 +1796,12 @@ class QuotaReserveSqlAlchemyTestCase(test.TestCase):
     def test_quota_reserve_overs(self):
         self.init_usage('test_project', 'volumes', 4, 0)
         self.init_usage('test_project', 'gigabytes', 10 * 1024, 0)
-        context = FakeContext('test_project', 'test_class')
+        ctxt = context.RequestContext('admin', 'test_project', is_admin=True)
         quotas = dict(volumes=5, gigabytes=10 * 1024, )
         deltas = dict(volumes=2, gigabytes=2 * 1024, )
         self.assertRaises(exception.OverQuota,
                           sqa_api.quota_reserve,
-                          context, self.resources, quotas,
+                          ctxt, self.resources, quotas,
                           deltas, self.expire, 0, 0)
 
         self.assertEqual(set([]), self.sync_called)
@@ -1829,10 +1821,10 @@ class QuotaReserveSqlAlchemyTestCase(test.TestCase):
     def test_quota_reserve_reduction(self):
         self.init_usage('test_project', 'volumes', 10, 0)
         self.init_usage('test_project', 'gigabytes', 20 * 1024, 0)
-        context = FakeContext('test_project', 'test_class')
+        ctxt = context.RequestContext('admin', 'test_project', is_admin=True)
         quotas = dict(volumes=5, gigabytes=10 * 1024, )
         deltas = dict(volumes=-2, gigabytes=-2 * 1024, )
-        result = sqa_api.quota_reserve(context, self.resources, quotas,
+        result = sqa_api.quota_reserve(ctxt, self.resources, quotas,
                                        deltas, self.expire, 0, 0)
 
         self.assertEqual(set([]), self.sync_called)
@@ -1864,54 +1856,75 @@ class QuotaVolumeTypeReservationTestCase(test.TestCase):
     def setUp(self):
         super(QuotaVolumeTypeReservationTestCase, self).setUp()
 
+        self.user_id = fake.USER_ID
+        self.project_id = fake.PROJECT_ID
+        self.context = context.RequestContext(
+            self.user_id, self.project_id, is_admin=True,
+        )
+
         self.volume_type_name = CONF.default_volume_type
         self.volume_type = db.volume_type_get_by_name(
-            context.get_admin_context(),
-            name=self.volume_type_name)
+            self.context, name=self.volume_type_name,
+        )
 
     @mock.patch.object(quota.QUOTAS, 'reserve')
     @mock.patch.object(quota.QUOTAS, 'add_volume_type_opts')
-    def test_volume_type_reservation(self,
-                                     mock_add_volume_type_opts,
-                                     mock_reserve):
-        my_context = FakeContext('MyProject', None)
-        volume = fake_volume.fake_volume_obj(my_context,
-                                             name= 'my_vol_name',
-                                             id= 'my_vol_id',
-                                             size= 1,
-                                             project_id= 'vol_project_id')
-        quota_utils.get_volume_type_reservation(my_context,
-                                                volume,
-                                                self.volume_type['id'])
+    def test_volume_type_reservation(
+        self,
+        mock_add_volume_type_opts,
+        mock_reserve,
+    ):
+        volume = fake_volume.fake_volume_obj(
+            self.context,
+            name='my_vol_name',
+            id=fake.VOLUME_ID,
+            size=1,
+            project_id='vol_project_id',
+        )
+        quota_utils.get_volume_type_reservation(
+            self.context,
+            volume,
+            self.volume_type['id'],
+        )
         reserve_opts = {'volumes': 1, 'gigabytes': volume.size}
         mock_add_volume_type_opts.assert_called_once_with(
-            my_context,
+            self.context,
             reserve_opts,
-            self.volume_type['id'])
-        mock_reserve.assert_called_once_with(my_context,
-                                             project_id='vol_project_id',
-                                             gigabytes=1,
-                                             volumes=1)
+            self.volume_type['id'],
+        )
+        mock_reserve.assert_called_once_with(
+            self.context,
+            project_id='vol_project_id',
+            gigabytes=1,
+            volumes=1,
+        )
 
     @mock.patch.object(quota.QUOTAS, 'reserve')
     def test_volume_type_reservation_with_type_only(self, mock_reserve):
-        my_context = FakeContext('MyProject', None)
-        volume = fake_volume.fake_volume_obj(my_context,
-                                             name='my_vol_name',
-                                             id='my_vol_id',
-                                             size=1,
-                                             project_id='vol_project_id')
-        quota_utils.get_volume_type_reservation(my_context,
-                                                volume,
-                                                self.volume_type['id'],
-                                                reserve_vol_type_only=True)
+        volume = fake_volume.fake_volume_obj(
+            self.context,
+            name='my_vol_name',
+            id=fake.VOLUME_ID,
+            size=1,
+            project_id='vol_project_id',
+        )
+        quota_utils.get_volume_type_reservation(
+            self.context,
+            volume,
+            self.volume_type['id'],
+            reserve_vol_type_only=True,
+        )
         vtype_volume_quota = "%s_%s" % ('volumes', self.volume_type['name'])
         vtype_size_quota = "%s_%s" % ('gigabytes', self.volume_type['name'])
-        reserve_opts = {vtype_volume_quota: 1,
-                        vtype_size_quota: volume.size}
-        mock_reserve.assert_called_once_with(my_context,
-                                             project_id='vol_project_id',
-                                             **reserve_opts)
+        reserve_opts = {
+            vtype_volume_quota: 1,
+            vtype_size_quota: volume.size,
+        }
+        mock_reserve.assert_called_once_with(
+            self.context,
+            project_id='vol_project_id',
+            **reserve_opts,
+        )
 
     @ddt.data({'count_snaps': True, 'negative': True},
               {'count_snaps': True, 'negative': False},
@@ -1932,21 +1945,22 @@ class QuotaVolumeTypeReservationTestCase(test.TestCase):
         It should work for negative and positive quotas.
         """
         self.override_config('no_snapshot_gb_quota', not count_snaps)
-        my_context = FakeContext('MyProject', None)
         snaps = [fake_snapshot.fake_db_snapshot(volume_size=1),
                  fake_snapshot.fake_db_snapshot(volume_size=2)]
-        volume = fake_volume.fake_volume_obj(my_context,
-                                             expected_attrs=['snapshots'],
-                                             name='my_vol_name',
-                                             id=fake.VOLUME_ID,
-                                             size=1,
-                                             project_id=fake.PROJECT_ID,
-                                             snapshots=snaps)
-        quota_utils.get_volume_type_reservation(my_context,
-                                                volume,
-                                                self.volume_type['id'],
-                                                reserve_vol_type_only=True,
-                                                negative=negative)
+        volume = fake_volume.fake_volume_obj(
+            self.context,
+            expected_attrs=['snapshots'],
+            name='my_vol_name',
+            id=fake.VOLUME_ID,
+            size=1,
+            project_id=fake.PROJECT_ID,
+            snapshots=snaps)
+        quota_utils.get_volume_type_reservation(
+            self.context,
+            volume,
+            self.volume_type['id'],
+            reserve_vol_type_only=True,
+            negative=negative)
 
         factor = -1 if negative else 1
         if count_snaps:
@@ -1956,10 +1970,12 @@ class QuotaVolumeTypeReservationTestCase(test.TestCase):
         vtype_volume_quota = "volumes_%s" % self.volume_type['name']
         vtype_snapshot_quota = "snapshots_%s" % self.volume_type['name']
         vtype_size_quota = "%s_%s" % ('gigabytes', self.volume_type['name'])
-        reserve_opts = {vtype_volume_quota: factor * 1,
-                        vtype_snapshot_quota: factor * 2,
-                        vtype_size_quota: factor * (volume['size'] +
-                                                    snaps_size)}
-        mock_reserve.assert_called_once_with(my_context,
-                                             project_id=fake.PROJECT_ID,
-                                             **reserve_opts)
+        reserve_opts = {
+            vtype_volume_quota: factor * 1,
+            vtype_snapshot_quota: factor * 2,
+            vtype_size_quota: factor * (volume['size'] + snaps_size),
+        }
+        mock_reserve.assert_called_once_with(
+            self.context,
+            project_id=fake.PROJECT_ID,
+            **reserve_opts)
