@@ -14,14 +14,15 @@
 
 """Unit tests for classes that are used to invoke DataCore SANsymphony API."""
 
-import mock
+from unittest import mock
+
+from oslo_utils import netutils
 from oslo_utils import units
-import six
 import suds
 from suds.sax import parser
 from suds import wsdl
 
-from cinder import test
+from cinder.tests.unit import test
 from cinder.volume.drivers.datacore import api
 from cinder.volume.drivers.datacore import exception
 
@@ -51,6 +52,13 @@ class DataCoreClientTestCase(test.TestCase):
                 'side_effect',
                 self._get_service_side_effect)
 
+        # TODO(tkajinam): Because of changes in netaddr 1.0.0, is_valid_ipv6 no
+        #                 longer "accept" non string object and raises
+        #                 TypeError. Patch the method until we properly mock
+        #                 internal behavior to present valid address strings.
+        mock_is_valid_ipv6 = self.mock_object(netutils, 'is_valid_ipv6')
+        mock_is_valid_ipv6.return_value = False
+
         self.client = api.DataCoreClient('hostname', 'username', 'password', 1)
         self.client.API_RETRY_INTERVAL = 0
 
@@ -709,7 +717,7 @@ class FaultDefinitionsFilterTestCase(test.TestCase):
         context = mock.Mock()
         sax = parser.Parser()
         wsdl_document = FAKE_WSDL_DOCUMENT
-        if isinstance(wsdl_document, six.text_type):
+        if isinstance(wsdl_document, str):
             wsdl_document = wsdl_document.encode('utf-8')
         context.document = sax.parse(string=wsdl_document).root()
         self.assertTrue(self._operation_has_fault(context.document,
