@@ -15,12 +15,13 @@
 
 import functools
 import unittest
+from unittest import mock
 
-import mock
 from oslo_utils import units
 
 from cinder import exception
 from cinder.tests.unit.volume.drivers.dell_emc.unity import test_adapter
+from cinder.tests.unit.volume.drivers.dell_emc.unity import test_driver
 from cinder.volume.drivers.dell_emc.unity import utils
 
 
@@ -28,6 +29,11 @@ def get_volume_type_extra_specs(volume_type):
     return {'provisioning:type': volume_type}
 
 
+def get_group_type_specs(group_type):
+    return {'consistent_group_snapshot_enabled': '<is> True',
+            'group_type_id': group_type}
+
+
 def get_volume_type_qos_specs(type_id):
     if type_id == 'invalid_backend_qos_consumer':
         ret = {'qos_specs': {'consumer': 'invalid'}}
@@ -72,6 +78,17 @@ def patch_volume_types(func):
     return func_wrapper
 
 
+def patch_group_types(func):
+    @functools.wraps(func)
+    @mock.patch(target=('cinder.volume.group_types'
+                        '.get_group_type_specs'),
+                new=get_group_type_specs)
+    def func_wrapper(*args, **kwargs):
+        return func(*args, **kwargs)
+
+    return func_wrapper
+
+
 class UnityUtilsTest(unittest.TestCase):
     def test_validate_pool_names_filter(self):
         all_pools = list('acd')
@@ -294,3 +311,70 @@ class UnityUtilsTest(unittest.TestCase):
         ret = utils.remove_empty(option, value_list)
         expected = None
         self.assertEqual(expected, ret)
+
+    @patch_group_types
+    def test_group_is_cg(self):
+        cg = test_driver.UnityDriverTest.get_cg()
+        result = utils.group_is_cg(cg)
+        self.assertTrue(result)
+
+    @patch_group_types
+    def test_get_group_specs_by_key(self):
+        cg = test_driver.UnityDriverTest.get_cg()
+        result = utils.get_group_specs(cg, 'consistent_group_snapshot_enabled')
+        self.assertEqual('<is> True', result)
+
+    @patch_group_types
+    def test_no_group_specs_key(self):
+        cg = test_driver.UnityDriverTest.get_cg()
+        result = utils.get_group_specs(cg, 'test_key')
+        self.assertIsNone(result)
+
+    @patch_volume_types
+    def test_retype_no_need_migration_when_same_host(self):
+        volume = test_adapter.MockOSResource(volume_type_id='host_1',
+                                             host='host_1')
+        new_host = {'name': 'new_name', 'host': 'host_1'}
+        ret = utils.retype_need_migration(volume, None, None, new_host)
+        self.assertFalse(ret)
+
+    @patch_volume_types
+    def test_retype_need_migration_when_diff_host(self):
+        volume = test_adapter.MockOSResource(volume_type_id='host_1',
+                                             host='host_1')
+        new_host = {'name': 'new_name', 'host': 'new_host'}
+        ret = utils.retype_need_migration(volume, None, None, new_host)
+        self.assertTrue(ret)
+
+    @patch_volume_types
+    def test_retype_no_need_migration_thin_to_compressed(self):
+        volume = test_adapter.MockOSResource(volume_type_id='host_1',
+                                             host='host_1')
+        new_host = {'name': 'new_name', 'host': 'host_1'}
+        old_provision = ''
+        new_provision = 'compressed'
+        ret = utils.retype_need_migration(volume, old_provision,
+                                          new_provision, new_host)
+        self.assertFalse(ret)
+
+    @patch_volume_types
+    def test_retype_no_need_migration_compressed_to_thin(self):
+        volume = test_adapter.MockOSResource(volume_type_id='host_1',
+                                             host='host_1')
+        new_host = {'name': 'new_name', 'host': 'host_1'}
+        old_provision = 'compressed'
+        new_provision = ''
+        ret = utils.retype_need_migration(volume, old_provision,
+                                          new_provision, new_host)
+        self.assertFalse(ret)
+
+    @patch_volume_types
+    def test_retype_need_migration_thin_to_thick(self):
+        volume = test_adapter.MockOSResource(volume_type_id='host_1',
+                                             host='host_1')
+        new_host = {'name': 'new_name', 'host': 'host_1'}
+        old_provision = ''
+        new_provision = 'thick'
+        ret = utils.retype_need_migration(volume, old_provision,
+                                          new_provision, new_host)
+        self.assertTrue(ret)
