@@ -15,18 +15,18 @@
 import unittest
 
 from cinder import exception
-from cinder import test
 from cinder.tests.unit.volume.drivers.dell_emc.vnx import fake_exception \
     as storops_ex
 from cinder.tests.unit.volume.drivers.dell_emc.vnx import fake_storops \
     as storops
 from cinder.tests.unit.volume.drivers.dell_emc.vnx import res_mock
+from cinder.tests.unit.volume.drivers.dell_emc.vnx import test_base
 from cinder.tests.unit.volume.drivers.dell_emc.vnx import utils
 from cinder.volume.drivers.dell_emc.vnx import client as vnx_client
 from cinder.volume.drivers.dell_emc.vnx import common as vnx_common
 
 
-class TestCondition(test.TestCase):
+class TestCondition(test_base.TestCase):
     @res_mock.patch_client
     def test_is_lun_io_ready_false(self, client, mocked):
         r = vnx_client.Condition.is_lun_io_ready(mocked['lun'])
@@ -44,17 +44,7 @@ class TestCondition(test.TestCase):
                           mocked['lun'])
 
 
-class TestClient(test.TestCase):
-    def setUp(self):
-        super(TestClient, self).setUp()
-        self.origin_timeout = vnx_common.DEFAULT_TIMEOUT
-        vnx_common.DEFAULT_TIMEOUT = 0
-        vnx_common.INTERVAL_30_SEC = 0
-
-    def tearDown(self):
-        super(TestClient, self).tearDown()
-        vnx_common.DEFAULT_TIMEOUT = self.origin_timeout
-        vnx_common.INTERVAL_30_SEC = 30
+class TestClient(test_base.TestCase):
 
     @res_mock.patch_client
     def test_create_lun(self, client, mocked):
@@ -186,9 +176,9 @@ class TestClient(test.TestCase):
 
     @res_mock.patch_client
     def test_delete_lun_exception(self, client, mocked):
-        self.assertRaisesRegexp(storops_ex.VNXDeleteLunError,
-                                'General lun delete error.',
-                                client.delete_lun, mocked['lun'].name)
+        self.assertRaisesRegex(storops_ex.VNXDeleteLunError,
+                               'General lun delete error.',
+                               client.delete_lun, mocked['lun'].name)
 
     @res_mock.patch_client
     def test_cleanup_async_lun(self, client, mocked):
@@ -309,6 +299,10 @@ class TestClient(test.TestCase):
     def test_modify_snapshot(self, client, mocked):
         client.modify_snapshot('snap_name', True, True)
 
+    @res_mock.patch_client
+    def test_restore_snapshot(self, client, mocked):
+        client.restore_snapshot('lun-id', 'snap_name')
+
     @res_mock.patch_client
     def test_create_cg_snapshot(self, client, mocked):
         snap = client.create_cg_snapshot('cg_snap_name', 'cg_name')
@@ -370,12 +364,12 @@ class TestClient(test.TestCase):
 
     @res_mock.patch_client
     def test_add_lun_to_sg_alu_in_use(self, client, mocked):
-        self.assertRaisesRegexp(storops_ex.VNXNoHluAvailableError,
-                                'No HLU available.',
-                                client.add_lun_to_sg,
-                                mocked['sg'],
-                                mocked['lun'],
-                                3)
+        self.assertRaisesRegex(storops_ex.VNXNoHluAvailableError,
+                               'No HLU available.',
+                               client.add_lun_to_sg,
+                               mocked['sg'],
+                               mocked['lun'],
+                               3)
 
     @res_mock.patch_client
     def test_update_consistencygroup_no_lun_in_cg(self, client, mocked):
@@ -566,9 +560,15 @@ class TestClient(test.TestCase):
     @res_mock.patch_client
     def test_get_running_policy(self, client, mocked):
         policy, is_new = client.get_running_policy()
-        self.assertEqual(policy.state in ['Running', 'Measuring'], True)
+        self.assertIn(policy.state, ['Running', 'Measuring'])
         self.assertFalse(is_new)
 
     @res_mock.patch_client
     def test_add_lun_to_ioclass(self, client, mocked):
         client.add_lun_to_ioclass('test_ioclass', 1)
+
+    @res_mock.patch_client
+    def test_set_max_luns_per_sg(self, client, mocked):
+        with utils.patch_vnxstoragegroup as patch_sg:
+            client.set_max_luns_per_sg(300)
+            patch_sg.set_max_luns_per_sg.assert_called_with(300)
