@@ -12,15 +12,15 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import ddt
 import json
-
-import mock
+from unittest import mock
 import uuid
 
+import ddt
+
 from cinder import exception
 from cinder import objects
-from cinder import test
+from cinder.tests.unit import test
 from cinder.volume import configuration as config
 from cinder.volume.drivers.fusionstorage import dsware
 from cinder.volume.drivers.fusionstorage import fs_client
@@ -98,9 +98,10 @@ class TestDSWAREDriver(test.TestCase):
              "QoS_support": False,
              "thin_provisioning_support": False,
              "vendor_name": "Huawei",
+             "storage_protocol": "SCSI",
              "pools":
-                 [{"pool_name": 'fake_pool_name', "total_capacity_gb": 2,
-                   "free_capacity_gb": 1}]}, retval)
+                 [{"pool_name": 'fake_pool_name', "total_capacity_gb": 2.0,
+                   "free_capacity_gb": 1.0}]}, retval)
         mock_query_pool_info.assert_called_once_with()
 
     @mock.patch.object(fs_client.RestCommon, 'keep_alive')
@@ -380,7 +381,7 @@ class TestDSWAREDriver(test.TestCase):
         retval, vol = self.fake_driver._attach_volume(
             "context", volume, "properties")
         self.assertEqual(
-            ({'device': {'path': b'fake_path'}}, volume), (retval, vol))
+            ({'device': {'path': 'fake_path'}}, volume), (retval, vol))
         mock__get_manager_ip.assert_called_once_with("properties")
         mock__check_volume_exist.assert_called_once_with(volume)
         mock_attach_volume.assert_called_once_with(volume.name, 'fake_ip')
