@@ -70,20 +70,24 @@ DEFAULT_CONNECTOR = {
 CTXT = cinder_context.get_admin_context()
 
 TEST_VOLUME = []
-for i in range(4):
+for i in range(5):
     volume = {}
     volume['id'] = '00000000-0000-0000-0000-{0:012d}'.format(i)
     volume['name'] = 'test-volume{0:d}'.format(i)
-    if i == 3:
+    volume['volume_type_id'] = '00000000-0000-0000-0000-{0:012d}'.format(i)
+    if i == 3 or i == 4:
         volume['provider_location'] = None
     else:
         volume['provider_location'] = '{0:d}'.format(i)
     volume['size'] = 128
     if i == 2:
         volume['status'] = 'in-use'
+    elif i == 4:
+        volume['status'] = None
     else:
         volume['status'] = 'available'
     volume = fake_volume.fake_volume_obj(CTXT, **volume)
+    volume.volume_type = fake_volume.fake_volume_type_obj(CTXT)
     TEST_VOLUME.append(volume)
 
 
@@ -579,12 +583,18 @@ class VStorageRESTISCSIDriverTest(test.TestCase):
         self.assertEqual(1, get_goodness_function.call_count)
 
     @mock.patch.object(requests.Session, "request")
-    def test_create_volume(self, request):
+    @mock.patch.object(volume_types, 'get_volume_type_extra_specs')
+    @mock.patch.object(volume_types, 'get_volume_type_qos_specs')
+    def test_create_volume(
+            self, get_volume_type_qos_specs, get_volume_type_extra_specs,
+            request):
         request.return_value = FakeResponse(202, COMPLETED_SUCCEEDED_RESULT)
+        get_volume_type_extra_specs.return_value = {}
+        get_volume_type_qos_specs.return_value = {'qos_specs': None}
         self.driver.common._stats = {}
         self.driver.common._stats['pools'] = [
             {'location_info': {'pool_id': 30}}]
-        ret = self.driver.create_volume(fake_volume.fake_volume_obj(self.ctxt))
+        ret = self.driver.create_volume(TEST_VOLUME[4])
         self.assertEqual('1', ret['provider_location'])
         self.assertEqual(2, request.call_count)
 
@@ -599,12 +609,18 @@ class VStorageRESTISCSIDriverTest(test.TestCase):
 
     @mock.patch.object(requests.Session, "request")
     @mock.patch.object(sqlalchemy_api, 'volume_get', side_effect=_volume_get)
-    def test_create_snapshot(self, volume_get, request):
+    @mock.patch.object(volume_types, 'get_volume_type_extra_specs')
+    @mock.patch.object(volume_types, 'get_volume_type_qos_specs')
+    def test_create_snapshot(
+            self, get_volume_type_qos_specs, get_volume_type_extra_specs,
+            volume_get, request):
         request.side_effect = [FakeResponse(200, GET_LDEV_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
                                FakeResponse(200, GET_SNAPSHOTS_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT)]
+        get_volume_type_extra_specs.return_value = {}
+        get_volume_type_qos_specs.return_value = {'qos_specs': None}
         self.driver.common._stats = {}
         self.driver.common._stats['pools'] = [
             {'location_info': {'pool_id': 30}}]
@@ -622,12 +638,18 @@ class VStorageRESTISCSIDriverTest(test.TestCase):
         self.assertEqual(4, request.call_count)
 
     @mock.patch.object(requests.Session, "request")
-    def test_create_cloned_volume(self, request):
+    @mock.patch.object(volume_types, 'get_volume_type_extra_specs')
+    @mock.patch.object(volume_types, 'get_volume_type_qos_specs')
+    def test_create_cloned_volume(
+            self, get_volume_type_qos_specs, get_volume_type_extra_specs,
+            request):
         request.side_effect = [FakeResponse(200, GET_LDEV_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
                                FakeResponse(200, GET_SNAPSHOTS_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT)]
+        get_volume_type_extra_specs.return_value = {}
+        get_volume_type_qos_specs.return_value = {'qos_specs': None}
         self.driver.common._stats = {}
         self.driver.common._stats['pools'] = [
             {'location_info': {'pool_id': 30}}]
@@ -636,12 +658,18 @@ class VStorageRESTISCSIDriverTest(test.TestCase):
         self.assertEqual(5, request.call_count)
 
     @mock.patch.object(requests.Session, "request")
-    def test_create_volume_from_snapshot(self, request):
+    @mock.patch.object(volume_types, 'get_volume_type_extra_specs')
+    @mock.patch.object(volume_types, 'get_volume_type_qos_specs')
+    def test_create_volume_from_snapshot(
+            self, get_volume_type_qos_specs, get_volume_type_extra_specs,
+            request):
         request.side_effect = [FakeResponse(200, GET_LDEV_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
                                FakeResponse(200, GET_SNAPSHOTS_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT)]
+        get_volume_type_extra_specs.return_value = {}
+        get_volume_type_qos_specs.return_value = {'qos_specs': None}
         self.driver.common._stats = {}
         self.driver.common._stats['pools'] = [
             {'location_info': {'pool_id': 30}}]
@@ -651,10 +679,13 @@ class VStorageRESTISCSIDriverTest(test.TestCase):
         self.assertEqual(5, request.call_count)
 
     @mock.patch.object(requests.Session, "request")
-    def test_initialize_connection(self, request):
+    @mock.patch.object(volume_types, 'get_volume_type_extra_specs')
+    def test_initialize_connection(
+            self, get_volume_type_extra_specs, request):
         request.side_effect = [FakeResponse(200, GET_HOST_ISCSIS_RESULT),
                                FakeResponse(200, GET_HOST_GROUP_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT)]
+        get_volume_type_extra_specs.return_value = {}
         ret = self.driver.initialize_connection(
             TEST_VOLUME[0], DEFAULT_CONNECTOR)
         self.assertEqual('iscsi', ret['driver_volume_type'])
@@ -674,12 +705,15 @@ class VStorageRESTISCSIDriverTest(test.TestCase):
         self.assertEqual(3, request.call_count)
 
     @mock.patch.object(requests.Session, "request")
-    def test_initialize_connection_shared_target(self, request):
+    @mock.patch.object(volume_types, 'get_volume_type_extra_specs')
+    def test_initialize_connection_shared_target(
+            self, get_volume_type_extra_specs, request):
         """Normal case: A target shared with other systems."""
         request.side_effect = [FakeResponse(200, NOTFOUND_RESULT),
                                FakeResponse(200, GET_HOST_GROUPS_RESULT),
                                FakeResponse(200, GET_HOST_ISCSIS_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT)]
+        get_volume_type_extra_specs.return_value = {}
         ret = self.driver.initialize_connection(
             TEST_VOLUME[0], DEFAULT_CONNECTOR)
         self.assertEqual('iscsi', ret['driver_volume_type'])
@@ -760,23 +794,29 @@ class VStorageRESTISCSIDriverTest(test.TestCase):
         self.assertEqual(6, request.call_count)
 
     @mock.patch.object(requests.Session, "request")
-    def test_manage_existing(self, request):
+    @mock.patch.object(volume_types, 'get_volume_type_qos_specs')
+    def test_manage_existing(self, get_volume_type_qos_specs, request):
         request.side_effect = [FakeResponse(200, GET_LDEV_RESULT),
-                               FakeResponse(202, COMPLETED_SUCCEEDED_RESULT)]
+                               FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
+                               FakeResponse(200, GET_LDEVS_RESULT)]
+        get_volume_type_qos_specs.return_value = {'qos_specs': None}
         ret = self.driver.manage_existing(
             TEST_VOLUME[0], self.test_existing_ref)
         self.assertEqual('1', ret['provider_location'])
-        self.assertEqual(2, request.call_count)
+        self.assertEqual(3, request.call_count)
 
     @mock.patch.object(requests.Session, "request")
-    def test_manage_existing_name(self, request):
+    @mock.patch.object(volume_types, 'get_volume_type_qos_specs')
+    def test_manage_existing_name(self, get_volume_type_qos_specs, request):
         request.side_effect = [FakeResponse(200, GET_LDEVS_RESULT),
                                FakeResponse(200, GET_LDEV_RESULT),
-                               FakeResponse(202, COMPLETED_SUCCEEDED_RESULT)]
+                               FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
+                               FakeResponse(200, GET_LDEVS_RESULT)]
+        get_volume_type_qos_specs.return_value = {'qos_specs': None}
         ret = self.driver.manage_existing(
             TEST_VOLUME[0], self.test_existing_ref_name)
         self.assertEqual('1', ret['provider_location'])
-        self.assertEqual(3, request.call_count)
+        self.assertEqual(4, request.call_count)
 
     @mock.patch.object(requests.Session, "request")
     def test_manage_existing_get_size(self, request):
@@ -884,12 +924,18 @@ class VStorageRESTISCSIDriverTest(test.TestCase):
         self.assertTupleEqual(actual, ret)
 
     @mock.patch.object(requests.Session, "request")
-    def test_create_group_from_src_volume(self, request):
+    @mock.patch.object(volume_types, 'get_volume_type_extra_specs')
+    @mock.patch.object(volume_types, 'get_volume_type_qos_specs')
+    def test_create_group_from_src_volume(
+            self, get_volume_type_qos_specs, get_volume_type_extra_specs,
+            request):
         request.side_effect = [FakeResponse(200, GET_LDEV_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
                                FakeResponse(200, GET_SNAPSHOTS_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT)]
+        get_volume_type_extra_specs.return_value = {}
+        get_volume_type_qos_specs.return_value = {'qos_specs': None}
         self.driver.common._stats = {}
         self.driver.common._stats['pools'] = [
             {'location_info': {'pool_id': 30}}]
@@ -903,12 +949,18 @@ class VStorageRESTISCSIDriverTest(test.TestCase):
         self.assertTupleEqual(actual, ret)
 
     @mock.patch.object(requests.Session, "request")
-    def test_create_group_from_src_snapshot(self, request):
+    @mock.patch.object(volume_types, 'get_volume_type_extra_specs')
+    @mock.patch.object(volume_types, 'get_volume_type_qos_specs')
+    def test_create_group_from_src_snapshot(
+            self, get_volume_type_qos_specs, get_volume_type_extra_specs,
+            request):
         request.side_effect = [FakeResponse(200, GET_LDEV_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
                                FakeResponse(200, GET_SNAPSHOTS_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT)]
+        get_volume_type_extra_specs.return_value = {}
+        get_volume_type_qos_specs.return_value = {'qos_specs': None}
         self.driver.common._stats = {}
         self.driver.common._stats['pools'] = [
             {'location_info': {'pool_id': 30}}]
@@ -921,7 +973,10 @@ class VStorageRESTISCSIDriverTest(test.TestCase):
             None, [{'id': TEST_VOLUME[0]['id'], 'provider_location': '1'}])
         self.assertTupleEqual(actual, ret)
 
-    def test_create_group_from_src_volume_error(self):
+    @mock.patch.object(volume_types, 'get_volume_type_qos_specs')
+    def test_create_group_from_src_volume_error(
+            self, get_volume_type_qos_specs):
+        get_volume_type_qos_specs.return_value = {'qos_specs': None}
         self.assertRaises(
             exception.VolumeDriverException, self.driver.create_group_from_src,
             self.ctxt, TEST_GROUP[1], [TEST_VOLUME[1]],
@@ -947,9 +1002,14 @@ class VStorageRESTISCSIDriverTest(test.TestCase):
     @mock.patch.object(requests.Session, "request")
     @mock.patch.object(sqlalchemy_api, 'volume_get', side_effect=_volume_get)
     @mock.patch.object(volume_utils, 'is_group_a_cg_snapshot_type')
+    @mock.patch.object(volume_types, 'get_volume_type_extra_specs')
+    @mock.patch.object(volume_types, 'get_volume_type_qos_specs')
     def test_create_group_snapshot_non_cg(
-            self, is_group_a_cg_snapshot_type, volume_get, request):
+            self, get_volume_type_qos_specs, get_volume_type_extra_specs,
+            is_group_a_cg_snapshot_type, volume_get, request):
         is_group_a_cg_snapshot_type.return_value = False
+        get_volume_type_extra_specs.return_value = {}
+        get_volume_type_qos_specs.return_value = {'qos_specs': None}
         request.side_effect = [FakeResponse(200, GET_LDEV_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
@@ -973,9 +1033,14 @@ class VStorageRESTISCSIDriverTest(test.TestCase):
     @mock.patch.object(requests.Session, "request")
     @mock.patch.object(sqlalchemy_api, 'volume_get', side_effect=_volume_get)
     @mock.patch.object(volume_utils, 'is_group_a_cg_snapshot_type')
+    @mock.patch.object(volume_types, 'get_volume_type_extra_specs')
+    @mock.patch.object(volume_types, 'get_volume_type_qos_specs')
     def test_create_group_snapshot_cg(
-            self, is_group_a_cg_snapshot_type, volume_get, request):
+            self, get_volume_type_qos_specs, get_volume_type_extra_specs,
+            is_group_a_cg_snapshot_type, volume_get, request):
         is_group_a_cg_snapshot_type.return_value = True
+        get_volume_type_extra_specs.return_value = {}
+        get_volume_type_qos_specs.return_value = {'qos_specs': None}
         request.side_effect = [FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
                                FakeResponse(202, COMPLETED_SUCCEEDED_RESULT),
