@@ -16,6 +16,7 @@
 
 from lxml import etree
 
+from cinder.tests.unit import fake_constants
 from cinder.volume.drivers.netapp.dataontap.client import api as netapp_api
 
 
@@ -440,6 +441,19 @@ FAKE_CMODE_POOL_MAP = {
     },
 }
 
+FAKE_CLUSTER_INFO = {
+    'name': 'jayaanancluster-1',
+    '_links': {
+        'self': {
+            'href': '/api/cluster'
+        }
+    }
+}
+
+FAKE_CLUSTER_POOL_MAP = {
+    'jayaanancluster-1': {'pool_name': 'jayaanancluster-1'}
+}
+
 FILE_LIST = ['file1', 'file2', 'file3']
 
 FAKE_LUN = netapp_api.NaElement.create_node_with_children(
@@ -768,6 +782,21 @@ test_volume.qos = {'qos_policy_group': None}
 test_volume.host = 'fakehost@backbackend#fakepool'
 test_volume.name = 'fakename'
 test_volume.size = SIZE
+test_volume.multiattach = False
+
+
+class test_namespace_volume(object):
+
+    def __getitem__(self, key):
+        return getattr(self, key)
+
+
+test_namespace_volume = test_namespace_volume()
+test_namespace_volume.name = NAMESPACE_NAME
+test_namespace_volume.size = SIZE
+test_namespace_volume.id = VOLUME_ID
+test_namespace_volume.host = HOST_STRING
+test_namespace_volume.attach_status = DETACHED
 
 
 class test_snapshot(object):
@@ -778,9 +807,9 @@ class test_snapshot(object):
 
 
 test_snapshot = test_snapshot()
-test_snapshot.id = 'fake_snap_id'
+test_snapshot.id = fake_constants.SNAPSHOT_ID
 test_snapshot.name = 'snapshot-%s' % test_snapshot.id
-test_snapshot.volume_id = 'fake_volume_id'
+test_snapshot.volume_id = fake_constants.VOLUME_ID
 test_snapshot.provider_location = PROVIDER_LOCATION
 
 
@@ -1021,5 +1050,6 @@ ADAPTIVE_QOS_POLICY_GROUP_INFO_REST = {
 
 REST_FIELDS = 'uuid,name,style'
 SUBSYSTEM = 'openstack-fake-subsystem'
+MAPPED_SUBSYSTEM = 'openstack-fake-mapped_subsystem'
 HOST_NQN = 'nqn.1992-01.example.com:string'
 TARGET_NQN = 'nqn.1992-01.example.com:target'
