@@ -13,12 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 """Tests for macrosan drivers."""
+from collections import UserDict
 import os
 import socket
 from unittest import mock
 
-from six.moves import UserDict
-
 from cinder import exception
 from cinder.tests.unit import test
 from cinder.volume import configuration as conf
