@@ -502,8 +502,10 @@ class SpdkDriverTestCase(test.TestCase):
         self.configuration = mock.Mock(conf.Configuration)
         self.configuration.target_helper = ""
         self.configuration.target_ip_address = "192.168.0.1"
+        self.configuration.target_secondary_ip_addresses = []
         self.configuration.target_port = 4420
         self.configuration.target_prefix = "nqn.2014-08.io.spdk"
+        self.configuration.nvmeof_conn_info_version = 1
         self.configuration.nvmet_port_id = "1"
         self.configuration.nvmet_ns_id = "fake_id"
         self.configuration.nvmet_subsystem_name = "2014-08.io.spdk"
@@ -514,6 +516,7 @@ class SpdkDriverTestCase(test.TestCase):
         mock_safe_get = mock.Mock()
         mock_safe_get.return_value = 'spdk-nvmeof'
         self.configuration.safe_get = mock_safe_get
+        self.configuration.lvm_share_target = False
         self.jsonrpcclient = JSONRPCClient()
         self.driver = spdk_driver.SPDKDriver(configuration=
                                              self.configuration)
@@ -794,7 +797,7 @@ class SpdkDriverTestCase(test.TestCase):
                             self.configuration.nvmet_subsystem_name,
                             self.driver.target_driver._get_first_free_node()
                         ),
-                        self.configuration.target_ip_address,
+                        [self.configuration.target_ip_address],
                         self.configuration.target_port, "rdma",
                         self.configuration.nvmet_ns_id
                     ),
@@ -832,7 +835,7 @@ class SpdkDriverTestCase(test.TestCase):
             self.driver.initialize_connection(db_volume, target_connector)
 
     def test_validate_connector(self):
-        mock_connector = {'initiator': 'fake_init'}
+        mock_connector = {'nqn': 'fake-nqn'}
         self.assertTrue(self.driver.validate_connector(mock_connector))
 
     def test_terminate_connection(self):
