@@ -16,31 +16,24 @@
 
 import itertools
 import re
-import sys
 from unittest import mock
 
 import ddt
+from os_brick.initiator import storpool_utils
+from os_brick.tests.initiator import test_storpool_utils
 from oslo_utils import units
 
-
-fakeStorPool = mock.Mock()
-fakeStorPool.spopenstack = mock.Mock()
-fakeStorPool.spapi = mock.Mock()
-fakeStorPool.spconfig = mock.Mock()
-fakeStorPool.sptypes = mock.Mock()
-sys.modules['storpool'] = fakeStorPool
-
-
 from cinder import exception
+from cinder.tests.unit import fake_constants
 from cinder.tests.unit import test
 from cinder.volume import configuration as conf
 from cinder.volume.drivers import storpool as driver
 
 
 volume_types = {
-    1: {},
-    2: {'storpool_template': 'ssd'},
-    3: {'storpool_template': 'hdd'}
+    fake_constants.VOLUME_TYPE_ID: {},
+    fake_constants.VOLUME_TYPE2_ID: {'storpool_template': 'ssd'},
+    fake_constants.VOLUME_TYPE3_ID: {'storpool_template': 'hdd'}
 }
 volumes = {}
 snapshots = {}
@@ -63,64 +56,52 @@ def mock_volume_types(f):
 
 
 def volumeName(vid):
-    return 'os--volume--{id}'.format(id=vid)
+    return 'os--volume-{id}'.format(id=vid)
 
 
-def snapshotName(vtype, vid):
-    return 'os--snap--{t}--{id}'.format(t=vtype, id=vid)
-
-
-class MockDisk(object):
-    def __init__(self, diskId):
-        self.id = diskId
-        self.generationLeft = -1
-        self.agCount = 14
-        self.agFree = 12
-        self.agAllocated = 1
-
-
-class MockVolume(object):
-    def __init__(self, v):
-        self.name = v['name']
-
-
-class MockTemplate(object):
-    def __init__(self, name):
-        self.name = name
-
-
-class MockApiError(Exception):
-    def __init__(self, msg):
-        super(MockApiError, self).__init__(msg)
+def snapshotName(vtype, vid, more=None):
+    return 'os--{t}--{m}--snapshot-{id}'.format(
+        t=vtype,
+        m="none" if more is None else more,
+        id=vid
+    )
 
 
 class MockAPI(object):
-    def __init__(self):
-        self._disks = {diskId: MockDisk(diskId) for diskId in (1, 2, 3, 4)}
-        self._disks[3].generationLeft = 42
+    def __init__(self, *args):
+        self._disks = {}
+        for disk_id in [1, 2, 3, 4]:
+            self._disks[disk_id] = {
+                'id': disk_id,
+                'generationLeft': -1,
+                'agCount': 14,
+                'agFree': 12,
+                'agAllocated': 1
+            }
+        self._disks[3]['generationLeft'] = 42
 
-        self._templates = [MockTemplate(name) for name in ('ssd', 'hdd')]
+        self._templates = [{'name': name} for name in ('ssd', 'hdd')]
 
-    def setlog(self, log):
-        self._log = log
-
-    def disksList(self):
+    def disks_list(self):
         return self._disks
 
-    def snapshotCreate(self, vname, snap):
+    def snapshot_create(self, vname, snap):
         snapshots[snap['name']] = dict(volumes[vname])
 
-    def snapshotUpdate(self, snap, data):
+    def snapshot_update(self, snap, data):
         sdata = snapshots[snap]
         sdata.update(data)
 
-    def snapshotDelete(self, name):
+    def snapshot_delete(self, name):
         del snapshots[name]
 
-    def volumeCreate(self, vol):
+    def volume_create(self, vol):
         name = vol['name']
         if name in volumes:
-            raise MockApiError('volume already exists')
+            raise storpool_utils.StorPoolAPIError(
+                'none',
+                {'error': {
+                    'descr': 'volume already exists'}})
         data = dict(vol)
 
         if 'parent' in vol and 'template' not in vol:
@@ -138,19 +119,22 @@ class MockAPI(object):
 
         volumes[name] = data
 
-    def volumeDelete(self, name):
+    def volume_delete(self, name):
         del volumes[name]
 
-    def volumesList(self):
-        return [MockVolume(v[1]) for v in volumes.items()]
+    def volumes_list(self):
+        the_volumes = []
+        for volume in volumes:
+            the_volumes.append({'name': volume})
+        return the_volumes
 
-    def volumeTemplatesList(self):
+    def volume_templates_list(self):
         return self._templates
 
-    def volumesReassign(self, json):
+    def volumes_reassign(self, json):
         pass
 
-    def volumeUpdate(self, name, data):
+    def volume_update(self, name, data):
         if 'size' in data:
             volumes[name]['size'] = data['size']
 
@@ -161,54 +145,23 @@ class MockAPI(object):
                 volumes[new_name]['name'] = new_name
             del volumes[name]
 
-    def volumeRevert(self, name, data):
+    def volume_revert(self, name, data):
         if name not in volumes:
-            raise MockApiError('No such volume {name}'.format(name=name))
+            raise storpool_utils.StorPoolAPIError(
+                'none',
+                {'error': {
+                    'descr': 'No such volume {name}'.format(name=name)}})
 
         snapname = data['toSnapshot']
         if snapname not in snapshots:
-            raise MockApiError('No such snapshot {name}'.format(name=snapname))
+            raise storpool_utils.StorPoolAPIError(
+                'none',
+                {'error': {
+                    'descr': 'No such snapshot {name}'.format(name=snapname)}})
 
         volumes[name] = dict(snapshots[snapname])
 
 
-class MockAttachDB(object):
-    def __init__(self, log):
-        self._api = MockAPI()
-
-    def api(self):
-        return self._api
-
-    def volumeName(self, vid):
-        return volumeName(vid)
-
-    def snapshotName(self, vtype, vid):
-        return snapshotName(vtype, vid)
-
-
-def MockVolumeRevertDesc(toSnapshot):
-    return {'toSnapshot': toSnapshot}
-
-
-def MockVolumeUpdateDesc(size):
-    return {'size': size}
-
-
-def MockSPConfig(section = 's01'):
-    res = {}
-    m = re.match('^s0*([A-Za-z0-9]+)$', section)
-    if m:
-        res['SP_OURID'] = m.group(1)
-    return res
-
-
-fakeStorPool.spapi.ApiError = MockApiError
-fakeStorPool.spconfig.SPConfig = MockSPConfig
-fakeStorPool.spopenstack.AttachDB = MockAttachDB
-fakeStorPool.sptypes.VolumeRevertDesc = MockVolumeRevertDesc
-fakeStorPool.sptypes.VolumeUpdateDesc = MockVolumeUpdateDesc
-
-
 class MockVolumeDB(object):
     """Simulate a Cinder database with a volume_get() method."""
 
@@ -226,7 +179,16 @@ class MockVolumeDB(object):
         }
 
 
+def MockSPConfig(section = 's01'):
+    res = {}
+    m = re.match('^s0*([A-Za-z0-9]+)$', section)
+    if m:
+        res['SP_OURID'] = m.group(1)
+    return res
+
+
 @ddt.ddt
+@mock.patch('os_brick.initiator.storpool_utils.get_conf', MockSPConfig)
 class StorPoolTestCase(test.TestCase):
 
     def setUp(self):
@@ -242,7 +204,16 @@ class StorPoolTestCase(test.TestCase):
 
         self.driver = driver.StorPoolDriver(execute=mock_exec,
                                             configuration=self.cfg)
-        self.driver.check_for_setup_error()
+
+        with (
+            mock.patch(
+                'os_brick.initiator.storpool_utils.get_conf'
+            ) as get_conf,
+            mock.patch(
+                'os_brick.initiator.storpool_utils.StorPoolAPI', MockAPI)
+        ):
+            get_conf.return_value = test_storpool_utils.SP_CONF
+            self.driver.check_for_setup_error()
 
     @ddt.data(
         (5, TypeError),
@@ -329,7 +300,8 @@ class StorPoolTestCase(test.TestCase):
         self.assertDictEqual({}, snapshots)
 
         self.driver.create_volume({'id': '1', 'name': 'v1', 'size': 1,
-                                   'volume_type': None})
+                                   'volume_type':
+                                       {'id': fake_constants.VOLUME_TYPE_ID}})
         self.assertCountEqual([volumeName('1')], volumes.keys())
         self.assertVolumeNames(('1',))
         v = volumes[volumeName('1')]
@@ -339,8 +311,9 @@ class StorPoolTestCase(test.TestCase):
 
         caught = False
         try:
-            self.driver.create_volume({'id': '1', 'name': 'v1', 'size': 0,
-                                       'volume_type': None})
+            self.driver.create_volume(
+                {'id': '1', 'name': 'v1', 'size': 0,
+                 'volume_type': {'id': fake_constants.VOLUME_TYPE_ID}})
         except exception.VolumeBackendAPIException:
             caught = True
         self.assertTrue(caught)
@@ -349,8 +322,9 @@ class StorPoolTestCase(test.TestCase):
         self.assertVolumeNames([])
         self.assertDictEqual({}, volumes)
 
-        self.driver.create_volume({'id': '1', 'name': 'v1', 'size': 2,
-                                   'volume_type': None})
+        self.driver.create_volume(
+            {'id': '1', 'name': 'v1', 'size': 2,
+             'volume_type': {'id': fake_constants.VOLUME_TYPE_ID}})
         self.assertVolumeNames(('1',))
         v = volumes[volumeName('1')]
         self.assertEqual(2 * units.Gi, v['size'])
@@ -358,23 +332,26 @@ class StorPoolTestCase(test.TestCase):
         self.assertEqual(3, v['replication'])
 
         self.driver.create_volume({'id': '2', 'name': 'v2', 'size': 3,
-                                   'volume_type': {'id': 1}})
+                                   'volume_type':
+                                       {'id': fake_constants.VOLUME_TYPE_ID}})
         self.assertVolumeNames(('1', '2'))
         v = volumes[volumeName('2')]
         self.assertEqual(3 * units.Gi, v['size'])
         self.assertIsNone(v['template'])
         self.assertEqual(3, v['replication'])
 
-        self.driver.create_volume({'id': '3', 'name': 'v2', 'size': 4,
-                                   'volume_type': {'id': 2}})
+        self.driver.create_volume(
+            {'id': '3', 'name': 'v2', 'size': 4,
+             'volume_type': {'id': fake_constants.VOLUME_TYPE2_ID}})
         self.assertVolumeNames(('1', '2', '3'))
         v = volumes[volumeName('3')]
         self.assertEqual(4 * units.Gi, v['size'])
         self.assertEqual('ssd', v['template'])
         self.assertNotIn('replication', v.keys())
 
-        self.driver.create_volume({'id': '4', 'name': 'v2', 'size': 5,
-                                   'volume_type': {'id': 3}})
+        self.driver.create_volume(
+            {'id': '4', 'name': 'v2', 'size': 5,
+             'volume_type': {'id': fake_constants.VOLUME_TYPE3_ID}})
         self.assertVolumeNames(('1', '2', '3', '4'))
         v = volumes[volumeName('4')]
         self.assertEqual(5 * units.Gi, v['size'])
@@ -400,10 +377,12 @@ class StorPoolTestCase(test.TestCase):
         self.assertDictEqual({}, snapshots)
 
         # Create two volumes
-        self.driver.create_volume({'id': '1', 'name': 'v1', 'size': 1,
-                                   'volume_type': None})
-        self.driver.create_volume({'id': '2', 'name': 'v2', 'size': 1,
-                                   'volume_type': None})
+        self.driver.create_volume(
+            {'id': '1', 'name': 'v1', 'size': 1,
+             'volume_type': {'id': fake_constants.VOLUME_TYPE_ID}})
+        self.driver.create_volume(
+            {'id': '2', 'name': 'v2', 'size': 1,
+             'volume_type': {'id': fake_constants.VOLUME_TYPE_ID}})
         self.assertCountEqual([volumeName('1'), volumeName('2')],
                               volumes.keys())
         self.assertVolumeNames(('1', '2',))
@@ -438,20 +417,27 @@ class StorPoolTestCase(test.TestCase):
         self.assertDictEqual({}, volumes)
         self.assertDictEqual({}, snapshots)
 
+    @mock_volume_types
     def test_clone_extend_volume(self):
         self.assertVolumeNames([])
         self.assertDictEqual({}, volumes)
         self.assertDictEqual({}, snapshots)
 
-        self.driver.create_volume({'id': '1', 'name': 'v1', 'size': 1,
-                                   'volume_type': None})
+        self.driver.create_volume(
+            {'id': '1', 'name': 'v1', 'size': 1,
+             'volume_type': {'id': fake_constants.VOLUME_TYPE_ID}})
         self.assertVolumeNames(('1',))
         self.driver.extend_volume({'id': '1'}, 2)
         self.assertEqual(2 * units.Gi, volumes[volumeName('1')]['size'])
 
         with mock.patch.object(self.driver, 'db', new=MockVolumeDB()):
             self.driver.create_cloned_volume(
-                {'id': '2', 'name': 'clo', 'size': 3, 'volume_type': None},
+                {
+                    'id': '2',
+                    'name': 'clo',
+                    'size': 3,
+                    'volume_type': {'id': fake_constants.VOLUME_TYPE_ID}
+                },
                 {'id': 1})
         self.assertVolumeNames(('1', '2'))
         self.assertDictEqual({}, snapshots)
@@ -468,24 +454,16 @@ class StorPoolTestCase(test.TestCase):
         self.assertDictEqual({}, snapshots)
 
     @ddt.data(*itertools.product(
-        [None] + [{'id': key} for key in sorted(volume_types.keys())],
-        [None] + [{'id': key} for key in sorted(volume_types.keys())]))
+        [{'id': key} for key in sorted(volume_types.keys())],
+        [{'id': key} for key in sorted(volume_types.keys())]))
     @ddt.unpack
     @mock_volume_types
     def test_create_cloned_volume(self, src_type, dst_type):
         self.assertDictEqual({}, volumes)
         self.assertDictEqual({}, snapshots)
 
-        src_template = (
-            None
-            if src_type is None
-            else volume_types[src_type['id']].get('storpool_template')
-        )
-        dst_template = (
-            None
-            if dst_type is None
-            else volume_types[dst_type['id']].get('storpool_template')
-        )
+        src_template = volume_types[src_type['id']].get('storpool_template')
+        dst_template = volume_types[dst_type['id']].get('storpool_template')
         src_name = 's-none' if src_template is None else 's-' + src_template
         dst_name = 'd-none' if dst_template is None else 'd-' + dst_template
 
@@ -553,8 +531,9 @@ class StorPoolTestCase(test.TestCase):
         self.assertEqual(21, pool['total_capacity_gb'])
         self.assertEqual(5, int(pool['free_capacity_gb']))
 
-        self.driver.create_volume({'id': 'cfgrepl1', 'name': 'v1', 'size': 1,
-                                   'volume_type': None})
+        self.driver.create_volume(
+            {'id': 'cfgrepl1', 'name': 'v1', 'size': 1,
+             'volume_type': {'id': fake_constants.VOLUME_TYPE_ID}})
         self.assertVolumeNames(('cfgrepl1',))
         v = volumes[volumeName('cfgrepl1')]
         self.assertEqual(3, v['replication'])
@@ -567,16 +546,18 @@ class StorPoolTestCase(test.TestCase):
         self.assertEqual(21, pool['total_capacity_gb'])
         self.assertEqual(8, int(pool['free_capacity_gb']))
 
-        self.driver.create_volume({'id': 'cfgrepl2', 'name': 'v1', 'size': 1,
-                                   'volume_type': None})
+        self.driver.create_volume(
+            {'id': 'cfgrepl2', 'name': 'v1', 'size': 1,
+             'volume_type': {'id': fake_constants.VOLUME_TYPE_ID}})
         self.assertVolumeNames(('cfgrepl2',))
         v = volumes[volumeName('cfgrepl2')]
         self.assertEqual(2, v['replication'])
         self.assertIsNone(v['template'])
         self.driver.delete_volume({'id': 'cfgrepl2'})
 
-        self.driver.create_volume({'id': 'cfgrepl3', 'name': 'v1', 'size': 1,
-                                   'volume_type': {'id': 2}})
+        self.driver.create_volume(
+            {'id': 'cfgrepl3', 'name': 'v1', 'size': 1,
+             'volume_type': {'id': fake_constants.VOLUME_TYPE2_ID}})
         self.assertVolumeNames(('cfgrepl3',))
         v = volumes[volumeName('cfgrepl3')]
         self.assertNotIn('replication', v)
@@ -599,16 +580,18 @@ class StorPoolTestCase(test.TestCase):
 
         self.driver.configuration.storpool_template = None
 
-        self.driver.create_volume({'id': 'cfgtempl1', 'name': 'v1', 'size': 1,
-                                   'volume_type': None})
+        self.driver.create_volume(
+            {'id': 'cfgtempl1', 'name': 'v1', 'size': 1,
+             'volume_type': {'id': fake_constants.VOLUME_TYPE_ID}})
         self.assertVolumeNames(('cfgtempl1',))
         v = volumes[volumeName('cfgtempl1')]
         self.assertEqual(3, v['replication'])
         self.assertIsNone(v['template'])
         self.driver.delete_volume({'id': 'cfgtempl1'})
 
-        self.driver.create_volume({'id': 'cfgtempl2', 'name': 'v1', 'size': 1,
-                                   'volume_type': {'id': 2}})
+        self.driver.create_volume(
+            {'id': 'cfgtempl2', 'name': 'v1', 'size': 1,
+             'volume_type': {'id': fake_constants.VOLUME_TYPE2_ID}})
         self.assertVolumeNames(('cfgtempl2',))
         v = volumes[volumeName('cfgtempl2')]
         self.assertNotIn('replication', v)
@@ -617,16 +600,18 @@ class StorPoolTestCase(test.TestCase):
 
         self.driver.configuration.storpool_template = 'hdd'
 
-        self.driver.create_volume({'id': 'cfgtempl3', 'name': 'v1', 'size': 1,
-                                   'volume_type': None})
+        self.driver.create_volume(
+            {'id': 'cfgtempl3', 'name': 'v1', 'size': 1,
+             'volume_type': {'id': fake_constants.VOLUME_TYPE_ID}})
         self.assertVolumeNames(('cfgtempl3',))
         v = volumes[volumeName('cfgtempl3')]
         self.assertNotIn('replication', v)
         self.assertEqual('hdd', v['template'])
         self.driver.delete_volume({'id': 'cfgtempl3'})
 
-        self.driver.create_volume({'id': 'cfgtempl4', 'name': 'v1', 'size': 1,
-                                   'volume_type': {'id': 2}})
+        self.driver.create_volume(
+            {'id': 'cfgtempl4', 'name': 'v1', 'size': 1,
+             'volume_type': {'id': fake_constants.VOLUME_TYPE2_ID}})
         self.assertVolumeNames(('cfgtempl4',))
         v = volumes[volumeName('cfgtempl4')]
         self.assertNotIn('replication', v)
@@ -643,10 +628,10 @@ class StorPoolTestCase(test.TestCase):
         # No volume type at all: 'default'
         ('default', None),
         # No storpool_template in the type extra specs: 'default'
-        ('default', {'id': 1}),
+        ('default', {'id': fake_constants.VOLUME_TYPE_ID}),
         # An actual template specified: 'template_*'
-        ('template_ssd', {'id': 2}),
-        ('template_hdd', {'id': 3}),
+        ('template_ssd', {'id': fake_constants.VOLUME_TYPE2_ID}),
+        ('template_hdd', {'id': fake_constants.VOLUME_TYPE3_ID}),
     )
     @ddt.unpack
     @mock_volume_types
@@ -656,6 +641,7 @@ class StorPoolTestCase(test.TestCase):
                              'volume_type': volume_type
                          }))
 
+    @mock_volume_types
     def test_volume_revert(self):
         vol_id = 'rev1'
         vol_name = volumeName(vol_id)
@@ -666,8 +652,9 @@ class StorPoolTestCase(test.TestCase):
         self.assertDictEqual({}, volumes)
         self.assertDictEqual({}, snapshots)
 
-        self.driver.create_volume({'id': vol_id, 'name': 'v1', 'size': 1,
-                                   'volume_type': None})
+        self.driver.create_volume(
+            {'id': vol_id, 'name': 'v1', 'size': 1,
+             'volume_type': {'id': fake_constants.VOLUME_TYPE_ID}})
         self.assertVolumeNames((vol_id,))
         self.assertDictEqual({}, snapshots)
 
