@@ -25,9 +25,9 @@ from oslo_utils import units
 from cinder import context
 from cinder import exception
 from cinder.image import image_utils
-from cinder import test
 from cinder.tests.unit import fake_snapshot
 from cinder.tests.unit import fake_volume
+from cinder.tests.unit import test
 from cinder.volume.drivers import vzstorage
 
 
@@ -419,8 +419,9 @@ class VZStorageTestCase(test.TestCase):
         mock_remotefs_create_cloned_volume.return_value = {
             'provider_location': self._FAKE_SHARE}
         ret = drv.create_cloned_volume(volume, src_vref)
+        # Bug #1875953: code should also be passing context here
         mock_remotefs_create_cloned_volume.assert_called_once_with(
-            volume, src_vref)
+            volume, src_vref, self.context)
         self.assertEqual(ret, {'provider_location': self._FAKE_SHARE})
 
     @mock.patch.object(vzstorage.VZStorageDriver, '_local_path_volume_info')
