@@ -26,10 +26,10 @@ from oslo_vmware import vim_util
 
 from cinder import context
 from cinder import exception as cinder_exceptions
-from cinder import test
 from cinder.tests.unit import fake_constants as fake
 from cinder.tests.unit import fake_snapshot
 from cinder.tests.unit import fake_volume
+from cinder.tests.unit import test
 from cinder.tests.unit import utils as test_utils
 from cinder.volume import configuration
 from cinder.volume.drivers.vmware import datastore as hub
