@@ -18,7 +18,7 @@
 """Unit tests for Cisco FC san lookup service."""
 
 from cinder import exception
-from cinder import test
+from cinder.tests.unit import test
 from cinder.volume import configuration as conf
 from cinder.zonemanager import fc_san_lookup_service as san_service
 
