@@ -345,16 +345,18 @@ class HBSDREPLICATION(rest.HBSDREST):
         """Create a primary volume and  a secondary volume."""
         pool_id = self.rep_secondary.storage_info['pool_id'][0]
         ldev_range = self.rep_secondary.storage_info['ldev_range']
+        qos_specs = utils.get_qos_specs_from_volume(volume)
         thread = greenthread.spawn(
             self.rep_secondary.create_ldev, volume.size, extra_specs,
-            pool_id, ldev_range)
+            pool_id, ldev_range, qos_specs=qos_specs)
         if pvol is None:
             try:
                 pool_id = self.rep_primary.get_pool_id_of_volume(volume)
                 ldev_range = self.rep_primary.storage_info['ldev_range']
                 pvol = self.rep_primary.create_ldev(volume.size,
                                                     extra_specs,
-                                                    pool_id, ldev_range)
+                                                    pool_id, ldev_range,
+                                                    qos_specs=qos_specs)
             except exception.VolumeDriverException:
                 self.rep_primary.output_log(MSG.CREATE_LDEV_FAILED)
         try:
@@ -385,7 +387,7 @@ class HBSDREPLICATION(rest.HBSDREST):
         return pvol, svol
 
     def _create_rep_copy_group_name(self, ldev):
-        return self.driver_info['target_prefix'] + '%s%02XU%02d' % (
+        return self.driver_info['target_prefix'] + '%s%02XG%02d' % (
             CONF.my_ip, self.conf.hitachi_replication_number, ldev >> 10)
 
     def _get_rep_copy_speed(self):
