@@ -13,8 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
-"""
-ISCSI volume driver for Inspur InStorage family and MCS storage systems.
+"""ISCSI volume driver for Inspur InStorage family and MCS storage systems.
 
 Notes:
 1. Make sure you config the password or key file. If you specify both
@@ -45,16 +44,14 @@ we must:
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
-import six
 
 from cinder import coordination
 from cinder import exception
 from cinder.i18n import _
 from cinder import interface
-from cinder import utils as cinder_utils
 from cinder.volume import driver
-
 from cinder.volume.drivers.inspur.instorage import instorage_common
+from cinder.volume import volume_utils
 
 LOG = logging.getLogger(__name__)
 
@@ -84,7 +81,7 @@ class InStorageMCSISCSIDriver(instorage_common.InStorageMCSCommonDriver,
     VERSION = "1.0.0"
 
     # ThirdPartySystems wiki page
-    CI_WIKI_NAME = "INSPUR_CI"
+    CI_WIKI_NAME = "Inspur_CI"
 
     def __init__(self, *args, **kwargs):
         super(InStorageMCSISCSIDriver, self).__init__(*args, **kwargs)
@@ -92,7 +89,7 @@ class InStorageMCSISCSIDriver(instorage_common.InStorageMCSCommonDriver,
         self.configuration.append_config_values(
             instorage_mcs_iscsi_opts)
 
-    @cinder_utils.trace
+    @volume_utils.trace
     @coordination.synchronized('instorage-host'
                                '{self._state[system_id]}'
                                '{connector[host]}')
@@ -134,7 +131,7 @@ class InStorageMCSISCSIDriver(instorage_common.InStorageMCSCommonDriver,
 
         return {'driver_volume_type': 'iscsi', 'data': properties}
 
-    @cinder_utils.trace
+    @volume_utils.trace
     def _get_single_iscsi_data(self, volume, connector, lun_id, chap_secret):
         volume_name = self._get_target_vol(volume)
         volume_attributes = self._assistant.get_vdisk_attributes(volume_name)
@@ -202,14 +199,14 @@ class InStorageMCSISCSIDriver(instorage_common.InStorageMCSCommonDriver,
                               discovery_auth_password=chap_secret)
         return properties
 
-    @cinder_utils.trace
+    @volume_utils.trace
     def _get_multi_iscsi_data(self, volume, connector, lun_id, properties):
         try:
             resp = self._assistant.ssh.lsportip()
         except Exception as ex:
             msg = (_('_get_multi_iscsi_data: Failed to '
                      'get port ip because of exception: '
-                     '%s.') % six.text_type(ex))
+                     '%s.') % str(ex))
             LOG.error(msg)
             raise exception.VolumeBackendAPIException(data=msg)
 
@@ -258,7 +255,7 @@ class InStorageMCSISCSIDriver(instorage_common.InStorageMCSCommonDriver,
             return self._do_terminate_connection(volume, connector, **kwargs)
         return _do_terminate_connection_locked()
 
-    @cinder_utils.trace
+    @volume_utils.trace
     def _do_terminate_connection(self, volume, connector, **kwargs):
         """Cleanup after an iSCSI connection has been terminated.
 
