@@ -19,6 +19,7 @@ import errno
 import os
 import tempfile
 import time
+import typing
 
 from castellan import key_manager
 from os_brick.remotefs import remotefs as remotefs_brick
@@ -100,9 +101,9 @@ class NfsDriver(remotefs.RemoteFSSnapDriverDistributed):
         self.configuration.append_config_values(nfs_opts)
         root_helper = utils.get_root_helper()
         # base bound to instance is used in RemoteFsConnector.
-        self.base = getattr(self.configuration,
-                            'nfs_mount_point_base')
-        self.base = os.path.realpath(self.base)
+        base = getattr(self.configuration,
+                       'nfs_mount_point_base')
+        self.base = os.path.realpath(base)
         opts = getattr(self.configuration,
                        'nfs_mount_options')
 
@@ -187,7 +188,7 @@ class NfsDriver(remotefs.RemoteFSSnapDriverDistributed):
         # If both nas_host and nas_share_path are set we are not
         # going to use the nfs_shares_config file.  So, only check
         # for its existence if it is going to be used.
-        if ((not nas_host) or (not nas_share_path)):
+        if (not nas_host) or (not nas_share_path):
             config = self.configuration.nfs_shares_config
             if not config:
                 msg = (_("There's no NFS config file configured (%s)") %
@@ -392,25 +393,28 @@ class NfsDriver(remotefs.RemoteFSSnapDriverDistributed):
             raise exception.ExtendVolumeError(reason='Insufficient space to'
                                               ' extend volume %s to %sG'
                                               % (volume.id, new_size))
-        path = self.local_path(volume)
+        # Use the active image file because this volume might have snapshot(s).
+        active_file = self.get_active_image_from_info(volume)
+        active_file_path = os.path.join(self._local_volume_dir(volume),
+                                        active_file)
         LOG.info('Resizing file to %sG...', new_size)
         file_format = None
         admin_metadata = objects.Volume.get_by_id(
             context.get_admin_context(), volume.id).admin_metadata
+
         if admin_metadata and 'format' in admin_metadata:
             file_format = admin_metadata['format']
-        image_utils.resize_image(path, new_size,
+        image_utils.resize_image(active_file_path, new_size,
                                  run_as_root=self._execute_as_root,
                                  file_format=file_format)
         if file_format == 'qcow2' and not self._is_file_size_equal(
-                path, new_size):
+                active_file_path, volume.name, new_size):
             raise exception.ExtendVolumeError(
                 reason='Resizing image file failed.')
 
-    def _is_file_size_equal(self, path, size):
+    def _is_file_size_equal(self, path, volume_name, size):
         """Checks if file size at path is equal to size."""
-        data = image_utils.qemu_img_info(path,
-                                         run_as_root=self._execute_as_root)
+        data = self._qemu_img_info(path, volume_name)
         virt_size = int(data.virtual_size / units.Gi)
         return virt_size == size
 
@@ -529,7 +533,9 @@ class NfsDriver(remotefs.RemoteFSSnapDriverDistributed):
         data = self._stats
 
         global_capacity = data['total_capacity_gb']
+        global_capacity = typing.cast(float, global_capacity)
         global_free = data['free_capacity_gb']
+        global_free = typing.cast(float, global_free)
 
         thin_enabled = self.configuration.nfs_sparsed_volumes
         if thin_enabled:
@@ -638,6 +644,8 @@ class NfsDriver(remotefs.RemoteFSSnapDriverDistributed):
         # when this snapshot was created.
         img_info = self._qemu_img_info(forward_path, snapshot.volume.name)
         path_to_snap_img = os.path.join(vol_path, img_info.backing_file)
+        snap_backing_file_img_info = self._qemu_img_info(path_to_snap_img,
+                                                         snapshot.volume.name)
 
         path_to_new_vol = self._local_path_volume(volume)
 
@@ -683,11 +691,13 @@ class NfsDriver(remotefs.RemoteFSSnapDriverDistributed):
                         'luks',
                         passphrase_file=new_pass_file.name,
                         src_passphrase_file=src_pass_file.name,
-                        run_as_root=self._execute_as_root)
+                        run_as_root=self._execute_as_root,
+                        data=snap_backing_file_img_info)
         else:
             image_utils.convert_image(path_to_snap_img,
                                       path_to_new_vol,
                                       out_format,
-                                      run_as_root=self._execute_as_root)
+                                      run_as_root=self._execute_as_root,
+                                      data=snap_backing_file_img_info)
 
         self._set_rw_permissions_for_all(path_to_new_vol)
