@@ -12,12 +12,12 @@
 
 """Driver for RackScale Design."""
 
-from distutils import version
 import json
 
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import units
+from packaging import version
 try:
     from rsd_lib import RSDLib
     from sushy import exceptions as sushy_exceptions
@@ -26,6 +26,7 @@ except ImportError:
     RSDLib = None
     sushy_exceptions = None
 
+from cinder.common import constants
 from cinder import exception
 from cinder.i18n import _
 from cinder import interface
@@ -80,15 +81,15 @@ class RSDClient(object):
             raise exception.VolumeBackendAPIException(
                 data=_("initialize: Cannot connect to RSD PODM."))
 
-        rsd_api_version = version.LooseVersion(rsdlib._rsd_api_version)
-        if rsd_api_version < version.LooseVersion("2.4.0"):
+        rsd_api_version = version.parse(rsdlib._rsd_api_version)
+        if rsd_api_version < version.parse("2.4.0"):
             raise exception.VolumeBackendAPIException(
                 data=(_("initialize: Unsupported rsd_api version: "
                         "%(current)s < %(expected)s.")
                       % {'current': rsdlib._rsd_api_version,
                          'expected': "2.4.0"}))
 
-        if rsdlib._redfish_version < version.LooseVersion("1.1.0"):
+        if version.parse(rsdlib._redfish_version) < version.parse("1.1.0"):
             raise exception.VolumeBackendAPIException(
                 data=(_("initialize: Unsupported rsd_lib version: "
                         "%(current)s < %(expected)s.")
@@ -594,7 +595,7 @@ class RSDDriver(driver.VolumeDriver):
         self._stats['volume_backend_name'] = backend_name
         self._stats['vendor_name'] = 'Intel'
         self._stats['driver_version'] = self.VERSION
-        self._stats['storage_protocol'] = 'nvmeof'
+        self._stats['storage_protocol'] = constants.NVMEOF_VARIANT_2
         # SinglePool
         self._stats['pools'] = [spool]
 
