@@ -23,6 +23,7 @@ from oslo_log import log as logging
 from oslo_vmware import pbm
 from oslo_vmware import vim_util
 
+from cinder import coordination
 from cinder.volume.drivers.vmware import exceptions as vmdk_exceptions
 
 
@@ -36,8 +37,9 @@ class DatastoreType(object):
     VMFS = "vmfs"
     VSAN = "vsan"
     VVOL = "vvol"
+    NFS41 = "nfs41"
 
-    _ALL_TYPES = {NFS, VMFS, VSAN, VVOL}
+    _ALL_TYPES = {NFS, VMFS, VSAN, VVOL, NFS41}
 
     @staticmethod
     def get_all_types():
@@ -53,11 +55,14 @@ class DatastoreSelector(object):
     PROFILE_NAME = "storageProfileName"
 
     # TODO(vbala) Remove dependency on volumeops.
-    def __init__(self, vops, session, max_objects):
+    def __init__(self, vops, session, max_objects, ds_regex=None):
         self._vops = vops
         self._session = session
         self._max_objects = max_objects
+        self._ds_regex = ds_regex
+        self._profile_id_cache = {}
 
+    @coordination.synchronized('vmware-datastore-profile-{profile_name}')
     def get_profile_id(self, profile_name):
         """Get vCenter profile ID for the given profile name.
 
@@ -65,12 +70,18 @@ class DatastoreSelector(object):
         :return: vCenter profile ID
         :raises ProfileNotFoundException:
         """
+        if profile_name in self._profile_id_cache:
+            LOG.debug("Returning cached ID for profile: %s.", profile_name)
+            return self._profile_id_cache[profile_name]
+
         profile_id = pbm.get_profile_id_by_name(self._session, profile_name)
         if profile_id is None:
             LOG.error("Storage profile: %s cannot be found in vCenter.",
                       profile_name)
             raise vmdk_exceptions.ProfileNotFoundException(
                 storage_profile=profile_name)
+
+        self._profile_id_cache[profile_name] = profile_id
         LOG.debug("Storage profile: %(name)s resolved to vCenter profile ID: "
                   "%(id)s.",
                   {'name': profile_name,
@@ -83,7 +94,8 @@ class DatastoreSelector(object):
         hubs = pbm.convert_datastores_to_hubs(cf, datastores)
         hubs = pbm.filter_hubs_by_profile(self._session, hubs, profile_id)
         hub_ids = [hub.hubId for hub in hubs]
-        return {k: v for k, v in datastores.items() if k.value in hub_ids}
+        return {k: v for k, v in datastores.items()
+                if vim_util.get_moref_value(k) in hub_ids}
 
     def _filter_datastores(self,
                            datastores,
@@ -107,11 +119,12 @@ class DatastoreSelector(object):
                 summary)
 
         valid_host_refs = valid_host_refs or []
-        valid_hosts = [host_ref.value for host_ref in valid_host_refs]
+        valid_hosts = [vim_util.get_moref_value(host_ref)
+                       for host_ref in valid_host_refs]
 
         def _is_ds_accessible_to_valid_host(host_mounts):
             for host_mount in host_mounts:
-                if host_mount.key.value in valid_hosts:
+                if vim_util.get_moref_value(host_mount.key) in valid_hosts:
                     return True
 
         def _is_ds_valid(ds_ref, ds_props):
@@ -120,11 +133,14 @@ class DatastoreSelector(object):
             if (summary is None or host_mounts is None):
                 return False
 
-            if (hard_anti_affinity_ds and
-                    ds_ref.value in hard_anti_affinity_ds):
+            if self._ds_regex and not self._ds_regex.match(summary.name):
                 return False
 
-            if summary.freeSpace < size_bytes:
+            if (hard_anti_affinity_ds and
+                    vim_util.get_moref_value(ds_ref) in hard_anti_affinity_ds):
+                return False
+
+            if summary.capacity == 0 or summary.freeSpace < size_bytes:
                 return False
 
             if (valid_hosts and
@@ -206,10 +222,10 @@ class DatastoreSelector(object):
         host_prop_map = {}
 
         def _is_host_usable(host_ref):
-            props = host_prop_map.get(host_ref.value)
+            props = host_prop_map.get(vim_util.get_moref_value(host_ref))
             if props is None:
                 props = self._get_host_properties(host_ref)
-                host_prop_map[host_ref.value] = props
+                host_prop_map[vim_util.get_moref_value(host_ref)] = props
 
             runtime = props.get('runtime')
             parent = props.get('parent')
@@ -220,12 +236,14 @@ class DatastoreSelector(object):
                 return False
 
         valid_host_refs = valid_host_refs or []
-        valid_hosts = [host_ref.value for host_ref in valid_host_refs]
+        valid_hosts = [vim_util.get_moref_value(host_ref)
+                       for host_ref in valid_host_refs]
 
         def _select_host(host_mounts):
             random.shuffle(host_mounts)
             for host_mount in host_mounts:
-                if valid_hosts and host_mount.key.value not in valid_hosts:
+                host_mount_key_value = vim_util.get_moref_value(host_mount.key)
+                if valid_hosts and host_mount_key_value not in valid_hosts:
                     continue
                 if (self._vops._is_usable(host_mount.mountInfo) and
                         _is_host_usable(host_mount.key)):
@@ -235,8 +253,9 @@ class DatastoreSelector(object):
         for ds_props in sorted_ds_props:
             host_ref = _select_host(ds_props['host'])
             if host_ref:
+                host_ref_value = vim_util.get_moref_value(host_ref)
                 rp = self._get_resource_pool(
-                    host_prop_map[host_ref.value]['parent'])
+                    host_prop_map[host_ref_value]['parent'])
                 return (host_ref, rp, ds_props['summary'])
 
     def select_datastore(self, req, hosts=None):
