@@ -596,17 +596,18 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
                     # and is detected as another format.
                     raise exception.Invalid()
 
-                if encryption['provider'] == 'luks':
+                encryption_provider = encryption['provider']
+                if encryption_provider == 'luks':
                     # Force ambiguous "luks" provider to luks1 for
                     # compatibility with new versions of cryptsetup.
-                    encryption['provider'] = 'luks1'
+                    encryption_provider = 'luks1'
 
                 (out, err) = utils.execute(
                     'cryptsetup',
                     '--batch-mode',
                     'luksFormat',
                     '--force-password',
-                    '--type', encryption['provider'],
+                    '--type', encryption_provider,
                     '--cipher', encryption['cipher'],
                     '--key-size', str(encryption['key_size']),
                     '--key-file=-',
@@ -739,12 +740,19 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
         urls = list(set([direct_url]
                         + [loc.get('url') for loc in locations or []]))
         image_volume_ids = self._extract_cinder_ids(urls)
+
+        filters = {'id': image_volume_ids}
+        if volume.cluster_name:
+            filters['cluster_name'] = volume.cluster_name
+        else:
+            filters['host'] = volume.host
+
         if self.driver.capabilities.get('clone_across_pools'):
             image_volumes = self.db.volume_get_all(
-                context, filters={'id': image_volume_ids})
+                context, filters=filters)
         else:
             image_volumes = self.db.volume_get_all_by_host(
-                context, volume['host'], filters={'id': image_volume_ids})
+                context, volume['host'], filters=filters)
 
         for image_volume in image_volumes:
             # For the case image volume is stored in the service tenant,
@@ -770,6 +778,8 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
             return None, False
 
         try:
+            # Drivers like NFS expect OVO and not SQLAlchemy object
+            image_volume = objects.Volume.get_by_id(context, image_volume.id)
             ret = self.driver.create_cloned_volume(volume, image_volume)
             self._cleanup_cg_in_volume(volume)
             return ret, True
@@ -851,11 +861,13 @@ class CreateVolumeFromSpecTask(flow_utils.CinderTask):
         except exception.SnapshotLimitReached:
             # If this exception occurred when cloning the image-volume,
             # it is because the image-volume reached its snapshot limit.
-            # Delete current cache entry and create a "fresh" entry
-            # NOTE: This will not delete the existing image-volume and
-            # only delete the cache entry
+            # Delete current cache entry and create a "fresh" entry.
             with excutils.save_and_reraise_exception():
-                self.image_volume_cache.evict(context, cache_entry)
+                msg = ('Deleting image-volume cache entry that reached its'
+                       ' cloning snapshot limit')
+                self.image_volume_cache.delete_cached_volume(context,
+                                                             cache_entry,
+                                                             msg)
         except NotImplementedError:
             LOG.warning('Backend does not support creating image-volume '
                         'clone. Image will be downloaded from Glance.')
