@@ -31,6 +31,9 @@ class Target(object, metaclass=abc.ABCMeta):
     well as force implementation of required methods.
 
     """
+    storage_protocol = None
+    SHARED_TARGET_SUPPORT = False
+    SECONDARY_IP_SUPPORT = True
 
     def __init__(self, *args, **kwargs):
         # TODO(stephenfin): Drop this in favour of using 'db' directly
@@ -68,3 +71,25 @@ class Target(object, metaclass=abc.ABCMeta):
     def terminate_connection(self, volume, connector, **kwargs):
         """Disallow connection from connector."""
         pass
+
+    @staticmethod
+    def are_same_connector(A, B):
+        """Whether 2 connectors belong to the same host or not.
+
+        This is used for multi attach volumes, to be able to know when there
+        are no more attachments on a given host.
+
+        This is the generic implementation, but specific targets may overwrite
+        it. For example iSCSI would check the the "initiator" key instead, and
+        NVMe-oF would check the "nqn" key.
+        """
+        a_host = A.get('host')
+        return a_host and (a_host == B.get('host'))
+
+    def extend_target(self, volume):
+        """Reinitializes a target after the volume has been extended.
+
+        Most drivers don't need to do anything, but in other cases this may
+        cause IO disruption.
+        """
+        pass
