@@ -14,8 +14,6 @@
 
 """Volume-related Utilities and helpers."""
 
-from __future__ import annotations  # Remove when only supporting python 3.9+
-
 import abc
 import ast
 import functools
@@ -995,6 +993,7 @@ def delete_encryption_key(context: context.RequestContext,
                  "cinder's service context.", encryption_key_id)
         conf = CONF
         ks_loading.register_auth_conf_options(conf, 'keystone_authtoken')
+        ks_loading.load_auth_from_conf_options(conf, 'keystone_authtoken')
         service_context = keystone_password.KeystonePassword(
             password=conf.keystone_authtoken.password,
             auth_url=conf.keystone_authtoken.auth_url,
@@ -1313,7 +1312,7 @@ def resolve_hostname(hostname: str) -> str:
     ip = socket.getaddrinfo(hostname, None)[0][4][0]
     LOG.debug('Asked to resolve hostname %(host)s and got IP %(ip)s.',
               {'host': hostname, 'ip': ip})
-    return ip
+    return str(ip)
 
 
 def update_backup_error(backup,
